import { Component, OnInit } from '@angular/core';
import { FormGroup, FormControl } from '@angular/forms';
import { ToastService } from 'src/app/services/toast.service';
import { UserService } from 'src/app/services/user.service';
import { takeUntil } from 'rxjs/operators';
import { Unsubscriber } from 'src/app/components/common/unsubscriber';
import { NavController } from '@ionic/angular';

@Component({
  selector: 'app-goal',
  templateUrl: './forgot-password.component.html',
  styleUrls: ['./forgot-password.component.scss']
})
export class ForgotPasswordComponent extends Unsubscriber implements OnInit {

  forgotPasswordForm: FormGroup = new FormGroup({
    email: new FormControl(''),
  });

  constructor(
    private toast: ToastService,
    private userService: UserService,
    private nav: NavController
  ) {
    super();
  }

  ngOnInit() {
  }

  onFormSubmit() {
    const email = this.forgotPasswordForm.get('email').value;
    if (!email) {
      this.toast.presentToast('Please enter your email address to send reset e-mail');
      return;
    }
    this.userService.sendForgotPassword(email).pipe(takeUntil(this._unsubscriber)).subscribe((res) => {
      this.nav.navigateBack('/auth');
      this.toast.presentToast('Please check your e-mail to reset your password');
    });
  }
}
