import { Component, OnInit } from '@angular/core';
import {AuthService} from '../../services/auth.service';
import {ActivatedRoute} from '@angular/router';
import {TokenService} from '../../services/token.service';
import {skip, takeUntil} from 'rxjs/operators';
import {NavController} from '@ionic/angular';
import {PatientService} from '../../services/patient.service';
import { UserService } from 'src/app/services/user.service';

@Component({
  selector: 'app-callback',
  templateUrl: './callback.component.html',
  styleUrls: ['./callback.component.scss'],
})
export class CallbackComponent implements OnInit {

  accessToken: string;
  redirectRoute: string;

  constructor(
      private route: ActivatedRoute,
      private authService: AuthService,
      private tokenService: TokenService,
      private nav: NavController,
      private patientService: PatientService,
      private userService: UserService
      ) {
  }

  ngOnInit() {
    // TODO: Add ability to read state from callback url to find redirect route
    this.route.fragment.subscribe(fragment => {
      const pairs = new URLSearchParams(fragment);
      this.accessToken = pairs.get('access_token');
      this.redirectRoute = pairs.get('redirect_route');
      this.autoLogin();
    });
  }

  private async autoLogin() {
    await this.tokenService.storeToken(this.accessToken);
    await this.authService.autoLogin().subscribe(() => {
      this.patientService.patients.pipe(skip(1)).subscribe(
          () => {
            this.routeAfterLogin();
          });
      this.patientService.getPatients();
    });
  }

  private async routeAfterLogin() {
    switch (this.redirectRoute) {
      case 'communication' :
        await this.nav.navigateRoot('/communication');
        break;
      default:
        const route = this.userService.isDoctor ? ['/patients'] : ['/timeline'];
        await this.nav.navigateRoot(route);
    }

  }
}
