import { Component, OnInit, forwardRef, OnDestroy } from '@angular/core';
import { ControlValueAccessor, NG_VALUE_ACCESSOR } from '@angular/forms';
import { BehaviorSubject } from 'rxjs';

@Component({
  selector: 'tw-progress-interactive',
  templateUrl: './progress-interactive.component.html',
  styleUrls: ['./progress-interactive.component.scss'],
  providers: [
    {
      provide: NG_VALUE_ACCESSOR,
      useExisting: forwardRef(() => ProgressInteractiveComponent),
      multi: true
    }
  ]
})
export class ProgressInteractiveComponent implements ControlValueAccessor {
  public _value: string;
  public rangeClass: string;

  onChanged: any = () => { };
  onTouched: any = () => { };

  writeValue(val: any) {
    this._value = val;
    this.rangeClass = this.getRangeClass(val);
  }

  registerOnChange(fn: any) {
    this.onChanged = fn;
  }
  registerOnTouched(fn: any) {
    this.onTouched = fn;
  }
  constructor() { }

  updateVal(val: any) {
    this._value = val.target.value;
    this.onTouched();
    this.onChanged(val.target.value);
    this.rangeClass = this.getRangeClass(val.target.value);
  }

  getRangeClass(val: any) {
    const rangeClasses = [ 'Maximum', 'Moderate', 'Minimum', 'Independent'];
    const index = +val === 0 ? 0 : Math.floor((+val - 1) / 25);
    return rangeClasses[index];
  }
}
