import { Component, OnInit, OnDestroy } from '@angular/core';
import { UserService } from 'src/app/services/user.service';
import { FormGroup, FormBuilder, Validators } from '@angular/forms';
import { GoalService, IGoalType } from 'src/app/services/goal.service';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { Observable } from 'rxjs';
import { NavController } from '@ionic/angular';

@Component({
  selector: 'app-goal-add',
  templateUrl: './goal-add.component.html',
  styleUrls: ['./goal-add.component.scss'],
})
export class GoalAddComponent implements OnInit, OnDestroy {
  public pageTitle = 'Add Goal';
  public goalForm: FormGroup;
  private goalSubscription;
  private routeSub;
  public goalTypes$: Observable<IGoalType[]>;
  public patientId;
  public actionSheetOptions = {
    header: 'Select Type',
    cssClass: 'custom-action-sheet'
  };

  constructor(
    public userService: UserService,
    private fb: FormBuilder,
    private goalService: GoalService,
    private route: ActivatedRoute,
    private nav: NavController
  ) { }

  ngOnInit() {
    this.goalForm = this.fb.group({
      name: [{ value: '', disabled: false }, Validators.required],
      type_id: [{ value: '', disabled: false }, Validators.required],
      description: [{ value: '', disabled: false }, Validators.required],
      patient_id: [{ value: '', disabled: false }]
    });

    this.routeSub = this.route.paramMap.subscribe((params: ParamMap) => {
      this.patientId = params.get('id');
      this.goalForm.get('patient_id').setValue(this.patientId);
    });

    this.goalTypes$ = this.goalService.getGoalTypes();
  }

  addGoal() {
    this.goalSubscription = this.goalService.createGoal(this.goalForm.value).subscribe((res) => {
      if (res && res.id) {
        this.nav.navigateForward(`patient/${this.patientId}/goals/${res.id}`);
      }
    });
  }

  ngOnDestroy() {
    if (this.goalSubscription) {
      this.goalSubscription.unsubscribe();
    }
    if (this.routeSub) {
      this.routeSub.unsubscribe();
    }
  }

}
