import { Component, OnInit } from '@angular/core';
import { NavController } from '@ionic/angular';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { UserService } from 'src/app/services/user.service';
import { switchMap, map, tap, } from 'rxjs/operators';
import { GoalService, IGoalsResponse } from 'src/app/services/goal.service';
import { Observable, of, BehaviorSubject, combineLatest } from 'rxjs';
import { IGoal } from 'src/app/models/server/goal';

@Component({
  selector: 'app-goals',
  templateUrl: './goals.component.html',
  styleUrls: ['./goals.component.scss'],
})
export class GoalsComponent implements OnInit {
  goals$: Observable<IGoal[]>;
  patientId;
  goalFilter$ = new BehaviorSubject<string>('current');
  filteredGoals$: Observable<IGoal[]>;

  constructor(
    private nav: NavController,
    private route: ActivatedRoute,
    public userService: UserService,
    private goalService: GoalService
  ) { }

  ngOnInit() {
    this.goals$ = this.route.paramMap.pipe(
      switchMap((params: ParamMap) => {
        this.patientId = params.get('id');
        return this.goalService.getGoals(this.patientId).pipe(
          map((res: IGoalsResponse) => res.goals)
        );
      })
    );

    this.filteredGoals$ = combineLatest([this.goals$, this.goalFilter$]).pipe(
      map(([goals, filter]) => {
        return goals ? goals.filter((goal) => {
          const goalInt = parseInt(goal.current_percentage, 10);
          if (filter === 'current') {
            return goalInt < 100;
          }
          if (filter === 'achieved') {
            return goalInt === 100;
          }
          return true;
        }) : [];
      })
    );
  }

  onGoalSelected(id: string) {
    this.nav.navigateForward([`/patient/${this.patientId}/goals`, { id }]);
  }

  updateFilter(filter: string) {
    this.goalFilter$.next(filter);
  }
}
