import {Component, OnInit, ElementRef, ViewChild} from '@angular/core';
import {Unsubscriber} from '../common/unsubscriber';
import {ActivatedRoute, NavigationExtras} from '@angular/router';
import {NavController, IonInput} from '@ionic/angular';
import {CommunicationService} from 'src/app/services/communication.service';
import {UserService} from '../../services/user.service';

// import {getUserDetails} from "../../../../../tw_api/src/services/CommunicationService";

@Component({
    selector: 'app-messages',
    templateUrl: './messages.component.html',
    styleUrls: ['./messages.component.scss'],
})

export class MessagesComponent extends Unsubscriber implements OnInit {
    public pageTitle;
    public fullName;
    public firstName;
    public lastName;
    public picture;
    public message = [];
    public newMessage;
    public newMessageOther;
    public contacts = [];
    public withHistory;
    private channelSid;
    private twilioClient;
    public twilioChannelMessages = [];
    private userId: string;
    private twilioChannel;
    private twilioUserToken;
    public isDoneLoading;

    @ViewChild('text') inputMessage: IonInput;
    any;

    constructor(
        private route: ActivatedRoute,
        private nav: NavController,
        private communicationService: CommunicationService,
        private userService: UserService,

    ) {
        super();
    }

    ngOnInit() {
        this.isDoneLoading = true;
        this.userId = this.userService.user.user_id;
        this.firstName = this.userService.user.first_name;
        this.lastName = this.userService.user.last_name;
        this.picture = this.userService.user.picture;

        this.route.queryParams.subscribe(params => {
            this.withHistory = params.withHistory;
            if (this.withHistory) {
                this.newMessage = false;
                this.newMessageOther = false;
                this.pageTitle = params.channel_name;
                this.channelSid = params.channel_sid;
                this.isDoneLoading = false;
                this.initializeTwilio();
            } else {
                this.newMessage = true;
                this.newMessageOther = true;
                if (params.contacts) {
                    // tslint:disable-next-line: forin
                    for (const property in params.contacts) {
                        this.fullName = params.contacts[property];
                        this.contacts.push(this.fullName);
                    }
                }
            }
        });
    }

    goToRecipients() {
        const navigationExtras: NavigationExtras = {
            queryParams: {
                isMessage: true
            }
        };

        this.nav.navigateForward([`/recipients`], navigationExtras);
    }

    removeContact(ev) {
        const index = this.contacts.indexOf(ev.toElement.title);

        if (index > -1) {
            this.contacts.splice(index, 1);
        }
    }

    sendMessage() {
        this.isDoneLoading = false;
        if (this.inputMessage.value && this.twilioChannelMessages.length > 0) {
            this.message.push(this.inputMessage.value);
            this.sendTwilioMessage();
            this.inputMessage.value = '';
        } else if (this.inputMessage.value &&  this.contacts.length > 0) {
            this.newMessage = false;
            this.pageTitle = this.contacts;
            this.message.push(this.inputMessage.value);
            this.startChannelMessage(this.inputMessage.value);
            this.inputMessage.value = '';
        }
        this.isDoneLoading = true;
    }

    // Initialize Twilio
    initializeTwilio() {
        this.communicationService.getUserMessageToken().subscribe(async res => {

            this.twilioUserToken = res.token;
            const Chat = require('twilio-chat');

            // Create Initialize the Chat Client
            this.twilioClient = new Chat.Client(this.twilioUserToken);

            await this.getChannelMessages();
            this.listenChannelMessages();

        });
    }

    // Start a New Message
    startChannelMessage(firstMessage) {
        this.isDoneLoading = false;
        this.communicationService.startMessage().subscribe(async res => {

            this.twilioUserToken = res.token;

            const Chat = require('twilio-chat');

            // Create the users if they do not exists
            res.recipientsAccessToken.forEach(token => {
                // tslint:disable-next-line: no-unused-expression
                (new Chat.Client(token));
            });

            // Create Initalize the Chat Client
            const client = new Chat.Client(this.twilioUserToken);
            const friendlyChannelName = res.friendlyChannelName;
            const uniqueChannelName = res.uniqueChannelName;

            const flagIsPrivate = true;

            client.createChannel({
                uniqueName: uniqueChannelName,
                friendlyName: friendlyChannelName,
                isPrivate: flagIsPrivate
            }).then(createdChannel => {
                this.twilioChannel = createdChannel;

                createdChannel.join().then(channel => {
                    // Sending First Message
                    const messageData = {
                        message: firstMessage,
                        userId: this.userId,
                        firstName: this.firstName,
                        lastName: this.lastName,
                        picture: this.picture,
                        updatedAt: new Date(),
                    };
                    channel.sendMessage(JSON.stringify(messageData));

                    this.twilioChannel.on('messageAdded', message => {
                        this.twilioChannelMessages.push(JSON.parse(message.body));
                    });

                    // Invite the Users to the Channel
                    res.recipientsIdentity.forEach(identity => {
                        createdChannel.invite(identity).then(() => {
                            console.log('Your friend has been invited!!');
                        });
                    });

                        // Send notifications
                    this.communicationService.sendMessageNotification().subscribe();
                    this.isDoneLoading = true;
                });
            });

        });
    }

    // Get Channel Messages from Twilio
    getChannelMessages() {

        // Get Channel By SID
        this.twilioClient.getChannelBySid(this.channelSid).then(channel => {
            this.twilioChannel = channel;

            // Get Messages from Twilio Message Per Channel
            channel.getMessages().then(messages => {
                // Loop through each message for the channel

                messages.items.forEach((item) => {
                    const message = JSON.parse(item.body);
                    this.twilioChannelMessages.push(message);
                });
            });
            this.isDoneLoading = true;
        });
    }

    // To Send Message
    sendTwilioMessage() {
        const messageData = {
            message: this.inputMessage.value,
            userId: this.userId,
            firstName: this.firstName,
            lastName: this.lastName,
            picture: this.picture,
            updatedAt: new Date()
        };

        this.twilioChannel.sendMessage(JSON.stringify(messageData));

        const recipientIds = [];

        // Get all users in channel
        this.twilioChannel.getMembers().then(async members => {
            members.forEach(member => {
                if (member.identity !== this.userId) {
                    recipientIds.push(member.identity);
                }
            });

            // Send notifications
            this.communicationService.createMewMessage(recipientIds);
            await this.communicationService.sendMessageNotification().subscribe();

        });
    }

    // Listening for Messages
    listenChannelMessages() {
        this.twilioClient.getChannelBySid(this.channelSid).then(channel => {
            this.twilioChannel = channel;

            this.twilioChannel.on('messageAdded', message => {
                this.twilioChannelMessages.push(JSON.parse(message.body));
            });
        });
    }

    convertDate(date) {
        date = new Date(date);

        return  date.toLocaleString();
    }
}
