import { Component, OnInit, Input } from '@angular/core';
import { ModalController, NavController } from '@ionic/angular';
import { PatientService } from 'src/app/services/patient.service';
import { Clipboard } from '@ionic-native/clipboard/ngx';
import { ToastService } from 'src/app/services/toast.service';

@Component({
  selector: 'app-explainer',
  templateUrl: './explainer.component.html',
  styleUrls: ['./explainer.component.scss'],
})
export class ExplainerComponent implements OnInit {
  @Input() notification;
  public title;
  public text;
  public icon;
  public image;
  public button;
  public route;
  public bulletText;
  public link;
  public linkText;

  constructor(
    private modalCtrl: ModalController,
    private nav: NavController,
    private patientService: PatientService,
    private clipboard: Clipboard,
    private toast: ToastService
  ) { }

  ngOnInit() {
    switch (this.notification.type) {
      case 'ONBOARDING_ROCKSTAR':
        this.title = 'Be a Pediatric Therapy Rockstar';
        this.text = `90 % of development happens
                    before age 7.
                    Here are 4 ways
                    to maximize therapy while
                    also freeing up more time for fun`;
        this.bulletText = `• View videos from your care team
                          • Comment or ask questions before your next visit
                          • Complete your daily workout
                          • Add videos to update your care team`;
        this.image = 'assets/icon/rock-on.svg';
        this.button = 'VIEW MY SESSIONS';
        this.route = `/timeline`;
        break;
      case 'ONBOARDING_CAREGIVER':
        this.title = 'Add Unlimited Caregivers';
        this.text = `Better communication results in better outcomes.
                  Add an unlimited number of people (Mom, Dad,
                  Grandma, Babysitter, etc.) to your team.`;
        this.icon = 'md-people';
        this.button = 'ADD MORE CAREGIVERS';
        this.route = `/settings/add-caregiver`;
        break;
      case 'ONBOARDING_ORGANIZATION':
        this.title = 'Connect Your Care Team! Add a Second Organization';
        this.text = ` Fact, The average
                  family receives care
                  from 3-5 different
                  organizations before
                  age 7.
                  Never lose progress
                  when you transition on your
                  journey. We will help get them
                  setup and answer any questions.`;
        this.icon = 'md-business';
        this.button = 'ADD NEW ORGANIZATION';
        this.route = `/settings/organization`;
        break;
      case 'ONBOARDING_DOCUMENT':
        this.title = 'Add Documents for Automatic Sharing';
        this.text = `Automatically share documents
                  with your therapy providers and
                  ditch the therapy binder. Add
                  any docs, photos, PDFs of any
                  programs, prescriptions, IEPs or
                  print outs.`;
        this.icon = 'md-cloud-upload';
        this.button = 'ADD NEW DOCUMENT';
        this.route = `patient/` + this.patientService.currentPatient.value.id + `/documents`;
        break;
      case 'ONBOARDING_WORKOUT':
        this.title = 'Daily workout exercises are short and impactful.';
        this.text = `When your therapist provides a
                  short coaching video, this is a
                  Daily Workout.
                  Your care team can practice
                  these daily, start a streak
                  between your group, and
                  maximize your opportunity to get
                  faster results.`;
        this.image = 'assets/icon/fitness_center-24px.svg';
        this.button = 'SEE DAILY WORKOUTS';
        this.route = `/workouts/` + this.patientService.currentPatient.value.id;
        break;
      case 'ONBOARDING_GOAL':
        this.title = 'Track Goals with Your Entire Team';
        this.text = `Automatically share goals with
                  all caregivers and therapy
                  providers.
                  Mark progress each
                  step of the way.`;
        this.icon = 'md-star-outline';
        this.button = 'Create Goals';
        this.route = `/patient/` + this.patientService.currentPatient.value.id + `/goals`;
        break;
      case 'TRAINING':
        this.title = 'Training Overview';
        this.text = `Have questions about how to use
                  the platform? Watch this short
                  training overview and send any
                  questions to
                  support@theraweconnect.com`;
        this.link = 'https://www.youtube.com/watch?v=9oXo92LEQvk&feature=youtu.be';
        this.linkText = `PROVIDER TRAINING LINK`;
        this.icon = 'md-star-outline';
        this.button = 'COPY THE LINK TO CLIPBOARD';
        this.route = `/copy`;
        break;
      case 'PARENT':
        this.title = 'Educate Caregivers';
        this.text = `If caregivers have questions
                  about how to use the platform,
                  you can share this training video
                  with them from YouTube.`;
        this.link = 'https://youtu.be/XmTfpK554SQ';
        this.linkText = `PARENT TRAINING LINK`;
        this.icon = 'md-star-outline';
        this.button = 'COPY THE LINK TO CLIPBOARD';
        this.route = `/copy`;
        break;
      case 'VIDEO':
        this.title = 'Live Video Chat';
        this.text = `Select a parent or therapist to
                  live video call via tablet or mobile app.`;
        this.icon = 'videocam';
        this.button = 'SELECT PERSON TO VIDEO CHAT';
        this.route = `/recipients`;
        break;
    }
  }

  close() {
    this.modalCtrl.dismiss();
  }

  goTo(route) {
    if (route === '/copy') {
      this.clipboard.copy(this.link);
      this.toast.presentToast('Copied to clipboard');
    } else {
      this.nav.navigateForward(route);
      this.close();
    }
  }

}
