import { Component, OnInit, Input, Output, EventEmitter } from '@angular/core';
import { ModalController, NavController } from '@ionic/angular';
import { ExplainerComponent } from '../explainer/explainer.component';
import { UserService } from 'src/app/services/user.service';
import { INotification } from 'src/app/models/server/Notification';
import * as moment from 'moment';

@Component({
    selector: 'app-notification-card',
    templateUrl: './notification-card.component.html',
    styleUrls: ['./notification-card.component.scss'],
})
export class NotificationCardComponent implements OnInit {
    @Input() notification;
    @Output() deleteNotification = new EventEmitter<INotification>();
    public title;
    public text;
    public date;
    public icon;
    public image;
    public disableDelete;
    public userName;
    public organization;

    constructor(private modalCtrl: ModalController, public userService: UserService, private nav: NavController) {}

    ngOnInit() {
        this.title = this.notification.header;
        this.text = this.notification.message;
        this.date = moment(this.notification.created_at).format('MMMM DD, YYYY');

        switch (this.notification.type) {
            case 'GUARDIAN_SESSION_COMMENT':
                this.icon = 'text';
                break;
            case 'SESSION_LOVE':
                this.icon = 'heart';
                break;
            case 'SESSION_VIDEO_VIEW':
                this.icon = 'eye';
                break;
            case 'WEEKLY_CHECK_IN_COMPLETE':
                this.icon = 'paper';
                break;
            // Parent Notification starts here
            case 'ONBOARDING_CAREGIVER':
                this.icon = 'md-people';
                break;
            case 'ONBOARDING_DOCUMENT':
                this.icon = 'md-cloud-upload';
                break;
            case 'ONBOARDING_GOAL':
                this.icon = 'md-star-outline';
                break;
            case 'ONBOARDING_ORGANIZATION':
                this.icon = 'md-business';
                break;
            case 'ONBOARDING_ROCKSTAR':
                this.image = 'assets/icon/rock-on.svg';
                break;
            case 'ONBOARDING_WORKOUT':
                this.image = 'assets/icon/fitness_center-24px.svg';
                break;
            default:
        }

        if (this.notification.id !== undefined) {
            this.disableDelete = false;
        } else {
            this.disableDelete = true;
        }
    }

    selectCard(notification) {
        switch (notification.type) {
            case 'SESSION_LOVE':
            case 'SESSION_VIDEO_VIEW':
            case 'GUARDIAN_SESSION_COMMENT':
            case 'THERAPIST_SESSION_COMMENT':
                case 'NEW_SESSION':
                if (!!notification && !!notification.params && !!notification.params.sessionId) {
                    this.nav.navigateForward(`/session/${notification.params.sessionId}`);
                }
                break;
            case 'ONBOARDING_CAREGIVER':
            case 'ONBOARDING_DOCUMENT':
            case 'ONBOARDING_GOAL':
            case 'ONBOARDING_ORGANIZATION':
            case 'ONBOARDING_ROCKSTAR':
            case 'ONBOARDING_WORKOUT':
                this.openExplainerModal(notification);
                break;
            default:
        }
    }

    removeCard(notification) {
        this.deleteNotification.emit(notification);
    }

    async openExplainerModal(notification) {
        const modal = await this.modalCtrl.create({
            component: ExplainerComponent,
            componentProps: {
                notification,
            },
        });

        await modal.present();
    }
}
