import { Component, OnInit } from '@angular/core';
import { BehaviorSubject } from 'rxjs';
import { INotification } from 'src/app/models/server/Notification';
import { NotificationService } from 'src/app/services/notification.service';
import { AlertController } from '@ionic/angular';

@Component({
  selector: 'app-notifications',
  templateUrl: './notifications.component.html',
  styleUrls: ['./notifications.component.scss'],
})
export class NotificationsComponent implements OnInit {
  public notifications$: BehaviorSubject<INotification[]> = new BehaviorSubject([]);
  public isEmpty;

  constructor(
    private notificationService: NotificationService,
    private alertController: AlertController
  ) { }

  ngOnInit() {
    this.notificationService.loadUserNotifications();
    this.notificationService.notifications.subscribe((val) => {
      this.notifications$.next(val);
      this.isEmpty = (val.length === 0);
    });
  }

  async removeCards() {
    const alert = await this.alertController.create({
      message: 'Are you sure you want to dismiss all notifications?',
      buttons: [
        {
          text: 'No',
          role: 'cancel',
          cssClass: 'secondary'
        }, {
          text: 'Yes',
          cssClass: 'dark',
          handler: () => {
            this.notificationService.deleteAllNotifications();
          }
        }
      ]
    });

    await alert.present();
  }

  removeCard(notification) {
    this.notificationService.deleteSingleNotification(notification.id);
  }
}
