import { Component, OnInit } from '@angular/core';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { PatientService } from 'src/app/services/patient.service';
import { StateService } from 'src/app/services/state.service';
import { switchMap, takeUntil } from 'rxjs/operators';
import { Unsubscriber } from '../common/unsubscriber';
import { Patient } from 'src/app/models/Server';
import { GetPatientResponse } from 'src/app/models/Http';
import { NavController } from '@ionic/angular';
import { SessionService } from 'src/app/services/session.service';
import * as moment from 'moment';

@Component({
  selector: 'app-patient',
  templateUrl: './patient.component.html',
  styleUrls: ['./patient.component.scss'],
})
export class PatientComponent extends Unsubscriber implements OnInit {
  pageTitle = 'Patient Profile';
  patient: Patient;
  public patientMetaData;
  constructor(
    private route: ActivatedRoute,
    private patientService: PatientService,
    public stateService: StateService,
    private nav: NavController,
    private sessionService: SessionService
    ) {
      super();
     }

  ngOnInit() {
    this.route.paramMap.pipe(
      switchMap((params: ParamMap) => {
        return this.patientService.getPatient(params.get('id'));
      }),
      takeUntil(this._unsubscriber)).subscribe((response: GetPatientResponse) => {
        this.patient = response.patient;
        this.patientService.setCurrentPatient(response.patient);
        this.patientMetaData = {
          commentsCount: response.commentsCount,
          attachmentViewCount: response.attachmentViewCount,
          reactionCount: response.reactionCount
        };
      });
  }

  goToLatestCommentSession(id) {
    this.sessionService.getSessions(id).subscribe((response: any) => {
      const sessions = response.sessions;
      const latestCommentSession = sessions.filter((s: any) => s.comments)
      .sort((a, b) => a.comments[0].created_at > b.comments[0].created_at ? -1 : 1);
      const sessionId = latestCommentSession[0].id;

      this.nav.navigateForward([`/patient/${id}/session/${sessionId}`]);
    });
  }

  goToCaregiverTeam() {
    this.nav.navigateForward([`settings/caregivers`]);
  }

  goToSessions() {
    this.nav.navigateForward([`/timeline`]);
  }

  addSession() {
    this.nav.navigateForward([`/patient/${this.patient.id}/session/null`]);
  }

  goToGoals() {
    this.nav.navigateForward([`/patient/${this.patient.id}/goals`]);
  }

  goToDocuments() {
    this.nav.navigateForward([`/patient/${this.patient.id}/documents`]);
  }

  goToSettings() {
    this.nav.navigateForward([`settings/child/${this.patient.id}`]);
  }
}
