import { Component, OnInit } from '@angular/core';
import { Patient } from '../../models/server/Patient';
import { PatientService } from 'src/app/services/patient.service';
import { Subscription } from 'rxjs';
import { NavController } from '@ionic/angular';
import { Unsubscriber } from '../common/unsubscriber';
import { takeUntil } from 'rxjs/operators';
import { NavigationExtras } from '@angular/router';
import { stringify } from '@angular/compiler/src/util';
import { NotificationService } from 'src/app/services/notification.service';
import {CommunicationService} from '../../services/communication.service';

@Component({
  selector: 'app-patients',
  templateUrl: './patients.component.html',
  styleUrls: ['./patients.component.scss'],
})
export class PatientsComponent extends Unsubscriber implements OnInit {
  pageTitle = 'Patients';
  patients: Patient[] = [];
  fakePatients: any[] = [{}, {}, {}, {}, {}, {}, {}, {}, {}, {}];
  sessionsLoading = false;
  showAddChild = true;
  showSpecific = true;
  searchType =  'people';
  notificationCount;
  chatMessageCount;

  constructor(
    private patientService: PatientService,
    private nav: NavController,
    private communicationService: CommunicationService,
    public notificationService: NotificationService
  ) {
    super();
   }

  ngOnInit() {
    // this.getPatients();
    // Polling Notification Count
   // setInterval(()=> this.notificationService.loadUserNotifications(), 1000);

    this.notificationService.notificationCount.subscribe((val) => {
      this.notificationCount = val;
    });

    this.notificationService.chatMessageCount.subscribe((val) => {
      this.chatMessageCount = val;
    });
  }
  // ionViewWillEnter() {
  //   this.notificationService.getUserNotifications().subscribe((val) => {
  //     this.notificationCount = val.notifications.length;
  //   });
  // }

  getPatients() {
    this.sessionsLoading = true;
    this.patientService.patients.pipe(takeUntil(this._unsubscriber)).subscribe(
      (patients) => {
          this.sessionsLoading = false;
          this.patients = patients;
      });
  }

  addPatient() {
    this.nav.navigateForward(['/patients/add-patient']);
  }

  searchPatient() {
    this.nav.navigateForward(['/patients/search-patient']);
  }

  switchSearchView() {
    if (this.searchType === 'people') {
      this.showSpecific = false;
      this.searchType = 'person';
      this.getPatients();
    } else {
      this.showSpecific = true;
      this.searchType = 'people';
      this.patients = [];
    }
  }

  onPatientSelected(id: string) {
    this.nav.navigateForward(['/patient', id]);
  }

  formattedOrgsLabel(orgs: any[]) {
    if (orgs && orgs.length) {
      const orgNames = orgs.map((org) => {
        return org.name;
      });
      return orgNames.join(',');
    } else {
      return '';
    }
  }

  getFilteredPatients(ev: any) {
    this.getPatients();

    const val = ev.target.value;

    if (val && val.trim() !== '') {
      this.patients = this.patients.filter((patient) => {
        const patientFullName = patient.first_name + ' ' + patient.last_name;
        return (patientFullName.toLowerCase().indexOf(val.toLowerCase()) > -1);
      });

      if (this.searchType === 'people') {
          this.showAddChild = false;
      }
    } else {
      this.patients = [];

      if (this.searchType === 'people') {
        this.showAddChild = true;
      }
    }
  }

  goToNotifications() {
    this.nav.navigateForward([`/notifications`]);
  }

}
