import { Component, OnInit, ViewChild } from '@angular/core';
import { Unsubscriber } from '../common/unsubscriber';
import { NavController, IonContent, ModalController } from '@ionic/angular';
import { CommunicationService } from 'src/app/services/communication.service';
import { ExplainerComponent } from '../notifications/explainer/explainer.component';
import { ToastService } from 'src/app/services/toast.service';
import { ActivatedRoute, NavigationExtras } from '@angular/router';

@Component({
  selector: 'app-recipients',
  templateUrl: './recipients.component.html',
  styleUrls: ['./recipients.component.scss'],
})
export class RecipientsComponent extends Unsubscriber implements OnInit {
  @ViewChild(IonContent) content: IonContent;
  public pageTitle = 'Communication Center';
  public patients;
  public contacts;
  public showNextButton = false;
  public isVideo;
  public isMessage;

  constructor(
    private communicationService: CommunicationService,
    private nav: NavController,
    private modalCtrl: ModalController,
    private toast: ToastService,
    private route: ActivatedRoute
  ) {
    super();
   }

  ngOnInit() {
    // this.openExplainerModal({type: 'VIDEO'});

    this.route.queryParams.subscribe(params => {
      this.isVideo = params.isVideo;
      this.isMessage = params.isMessage;
    });



    this.getRecipients();
  }

  ionViewDidLeave() {
    this.content.scrollToTop();
    this.getRecipients();
  }

  getRecipients() {
    this.communicationService.getContacts().subscribe((res) => {
      res.forEach(c => c.isSelected = false);
      this.contacts = res;
    });
  }

  async getFilteredRecipientsByType(userType: any) {
    this.contacts = await this.communicationService.getContacts().toPromise();
    this.contacts = this.contacts.filter((recipient) => {
      const isDoctor = recipient.is_doctor;
      return ((userType === 'parents' && isDoctor === false) || (userType !== 'parents' && isDoctor === true));
    });
  }

  btnActivate(ionicButton) {
    ionicButton.color =  'primary';
  }

  btnDeactivate(ionicButton) {
    ionicButton.color =  'grey-xl';
  }

  async getFilteredRecipients(ev: any) {
    this.contacts = await this.communicationService.getContacts().toPromise();

    const val = ev.target.value;

    if (val && val.trim() !== '') {
      this.contacts = this.contacts.filter((recipient) => {
        const recipientFullName = recipient.first_name + ' ' + recipient.last_name;
        return (recipientFullName.toLowerCase().indexOf(val.toLowerCase()) > -1);
      });
    }
  }

  onChange() {
    const selectedContactIds = this.contacts.filter(c => c.isSelected).map(c => c.user_id);
    // if (selectedContactIds.length > 1 || selectedContactIds.length < 1) {
    //   this.showNextButton = false;
      // if (selectedContactIds.length > 1) {
      //   this.toast.presentToast('Please select only one person to video call. Multiple people in a room is coming in May!');
      // }
    // } else {
    this.showNextButton = true;
    // }
  }

  communicationOption() {
    if (this.isMessage) {
      this.startMessage();
    } else {
      this.startVideoCall();
    }
  }

  startVideoCall() {
    const selectedContactIds = this.contacts.filter(c => c.isSelected).map(c => c.user_id);
    this.communicationService.createNewCall(selectedContactIds);
    this.nav.navigateForward(`/video`);
  }

  startMessage() {
    const selectedContacts = this.contacts.filter(c => c.isSelected).map(c => c.first_name + ' ' + c.last_name);
    const navigationExtras: NavigationExtras = {
        queryParams: {
          contacts: selectedContacts,
        }
    };
    const selectedContactIds = this.contacts.filter(c => c.isSelected).map(c => c.user_id);
    this.communicationService.createMewMessage(selectedContactIds);
    this.nav.navigateForward([`/messages`], navigationExtras);
  }

  async openExplainerModal(notification) {
    const modal = await this.modalCtrl.create({
      component: ExplainerComponent,
      componentProps: {
        notification
      }
    });

    await modal.present();
  }
}
