import { Component, OnInit } from '@angular/core';
import { Patient } from '../../models/server/Patient';
import { PatientService } from 'src/app/services/patient.service';
import { takeUntil, switchMap } from 'rxjs/operators';
import { Unsubscriber } from '../common/unsubscriber';
import { NavController } from '@ionic/angular';
import { SessionService } from 'src/app/services/session.service';
import * as moment from 'moment';
import { ParamMap } from '@angular/router';

@Component({
  selector: 'app-session-search',
  templateUrl: './session-search.component.html',
  styleUrls: ['./session-search.component.scss'],
})
export class SessionSearchComponent extends Unsubscriber implements OnInit {
  public pageTitle = 'Sessions';
  patients: Patient[] = [];
  searchQuery = '';
  sessions: any[] = [];
  route: any;

  constructor(
    private patientService: PatientService,
    private nav: NavController,
    private sessionService: SessionService
  ) {
    super();
  }

  ngOnInit() {
    // this.getSessions();
  }

  getSessions() {
    return new Promise<any[]>(res => {
      this.patientService.currentPatient.pipe(
        switchMap((patient: Patient) => {
          if (patient && patient.id) {
            return this.sessionService.getSessions(patient.id);
          } else {
            return this.sessionService.getSessions(this.patientService.patients.value[0].id);
          }
        }),
        takeUntil(this._unsubscriber)).subscribe((response: any) => {
          const sessions = response.sessions;
          for (const s of sessions) {
            s.created_date = moment(s.created_date).format('MM-DD-YYYY');
            if (s.thumbnail_url !== null) {
              if (s.thumbnail_url.indexOf('jpg') !== -1) {
                s.showThumbnail = true;
              } else {
                s.showThumbnail = false;
              }
            }
            res(sessions);
          }
        });
      });
  }

  async getFilteredSessions(ev: any) {
    this.sessions = await this.getSessions();

    const val = ev.target.value;
    if (val && val.trim() !== '') {
      this.sessions = this.sessions.filter((session) => {

        const organizationName = session.organization_name.toLowerCase().indexOf(val.toLowerCase()) > -1;
        const creatorName = session.creator_name.toLowerCase().indexOf(val.toLowerCase()) > -1;
        const tagsList = session.tags_list === null ? false : session.tags_list.toLowerCase().indexOf(val.toLowerCase()) > -1;

        const hasData = organizationName || creatorName || tagsList ? true : false ;
        return hasData;
      });
    } else {
      this.sessions = [];
    }
  }

  formatTags(tagString) {
    if (tagString && tagString.length) {
      return tagString.toLowerCase().split(';').filter((item, index) => index < 4);
    } else {
      return [];
    }
  }

  onSessionSelected(session) {
    this.nav.navigateForward([`/patient/session/${session.id}`]);
  }

}
