import { Component, OnInit, NgZone, ViewChild } from '@angular/core';
import { Session, Patient } from 'src/app/models/Server';
import * as moment from 'moment';
import { ActivatedRoute, Params, ParamMap } from '@angular/router';
import { SessionService } from 'src/app/services/session.service';

import { Unsubscriber } from '../common/unsubscriber';
import { SessionAttachment } from '../../models/client/SessionAttachment';
import { ToastService } from 'src/app/services/toast.service';
import { ActionSheetController, ModalController, Platform, NavController, IonContent } from '@ionic/angular';
import { MediaCapture, MediaFile, CaptureError, CaptureVideoOptions } from '@ionic-native/media-capture/ngx';
import { Plugins, CameraResultType, CameraSource } from '@capacitor/core';
import { PhotoViewer } from '@ionic-native/photo-viewer/ngx';

import { DomSanitizer } from '@angular/platform-browser';
import { SessionTagsComponent } from './session-tags/session-tags.component';
const { CapacitorVideoPlayer, Camera } = Plugins;
import { BehaviorSubject, forkJoin, Observable, of } from 'rxjs';
import { Camera as CordovaCamera } from '@ionic-native/camera/ngx';
import { takeUntil, map } from 'rxjs/operators';
import { FileTransferService } from 'src/app/services/file-transfer.service';
import { PatientService } from 'src/app/services/patient.service';
import { SessionNotesComponent } from './session-notes/session-notes.component';
import { GetCommentResponse } from 'src/app/models/http/GetCommentResponse';
import { SessionComment } from 'src/app/models/server/SessionComment';
import { StateService } from 'src/app/services/state.service';
import { SessionCompleteComponent } from './session-complete/session-complete.component';
import { LoadingContentComponent } from './loading-content/loading-content.component';
import { UserService } from 'src/app/services/user.service';
import { MediaService } from 'src/app/services/media.service';
import { SessionViewAttachmentComponent } from './session-view-attachment/session-view-attachment.component';
import { WebVideoComponent } from './web-video/web-video.component';
import { UploadService, ContentType, UploadType, PluginContentModel } from 'src/app/services/upload/upload.service';
import { DocumentService } from 'src/app/services/document.service';
import { FileUploadState, FileService } from 'src/app/services/file.service';
import { JWT_OPTIONS } from '@auth0/angular-jwt';
import { UIFileState } from 'src/app/models/interfaces/ui-file-state';
import { UiUserDocumentModel } from 'src/app/models/client/ui-user-document-model';
declare var PKVideoThumbnail: any;

@Component({
  selector: 'app-session',
  templateUrl: './session.component.html',
  styleUrls: ['./session.component.scss'],
})
export class SessionComponent extends Unsubscriber implements OnInit {
  public patient$: Patient;
  public newComment = {
    text: null,
    attachment: null,
    attachmentPath: null,
    mimeType: null,
    isWeb: false
  };
  public canComment = false;
  public edit = false;
  public session: Session;
  public sessionId: string | null;
  public slideOpts = {
    initialSlide: 0,
    speed: 400,
    centeredSlides: false,
    slidesPerView: 'auto',
    freeMode: true
  };
  public isPublished = false;
  public session$: BehaviorSubject<Session | {}> = new BehaviorSubject({});
  public comments$: Observable<SessionComment[]>;
  public attachments = [];
  public attachmentsUploading = [];
  public uploadsFinished: Array<string> = [];
  public attachments$: BehaviorSubject<SessionAttachment[]> = new BehaviorSubject([]);
  public attachmentsUploading$: BehaviorSubject<any[]> = new BehaviorSubject([]);
  private _sessionLikes;
  public sessionDate;
  @ViewChild(IonContent) content: IonContent;
  public showAttachments = true;
  public showLoveDialog;
  public showCommentDialog;
  public uploading = false;
  public isComment = false;

  constructor(
    private route: ActivatedRoute,
    private sessionService: SessionService,
    private toast: ToastService,
    private actionCtrl: ActionSheetController,
    private mediaCapture: MediaCapture,
    private sanitizer: DomSanitizer,
    private modalCtrl: ModalController,
    private cordovaCam: CordovaCamera,
    private fileTransferService: FileTransferService,
    private patientService: PatientService,
    public stateService: StateService,
    public userService: UserService,
    private ngZone: NgZone,
    private nav: NavController,
    private photoViewer: PhotoViewer,
    private mediaService: MediaService,
    public plt: Platform,
    private uploadService: UploadService,
    private documentService: DocumentService,
    private fileService: FileService
  ) {
    super();
  }

  ngOnInit() {
    this.route.paramMap.subscribe((params: Params) => {
      this.sessionId = params.get('session_id') !== 'null' ? params.get('session_id') : null;
      if (!!this.sessionId) {
        this.fetchSessionData();
        this.newComment.text = '';
        this.canComment = true;
        this.edit = this.userService.isDoctor ? true : false;
        this.getComments();
      } else {
        const patientId = params.get('id');
        if (!patientId) {
          this.showLoadError();
        }
        this.fetchPatient(patientId);
        this.canComment = false;
        this.createNewSession(patientId);
      }
    });

    this.session$.pipe().subscribe((res: Session) => {
      this.session = res;
      this.isPublished = res.state === 'PUBLISHED' ? true : false;
    });

    this.fileTransferService.uploadComplete$.subscribe((uploadId) => {
      this.ngZone.run(() => {
        const foundIndex = this.attachmentsUploading.findIndex(a => a.uploadId === uploadId);
        if (foundIndex > -1) {
          this.fetchAttachment(this.attachmentsUploading[foundIndex].attachment_id, foundIndex);
        } else {
          this.uploadsFinished.push(uploadId);
        }
      });
    });

    this.route.queryParams.subscribe(params => {
      if (params.goToBottom) {
        setTimeout(() => {
          this.scrollToBottom();
        }, 1500);
      }
    });
  }

  private showLoadError() {
    this.toast.presentToast('Error loading session. Please try again.');
    this.routeToHome();
  }

  private routeToHome() {
    if (this.userService.isDoctor) {
      this.nav.navigateForward([`/patient/${this.patient$.id}`]);
    } else {
      this.nav.navigateRoot(`/timeline`);
    }
  }

  createNewSession(patientId) {
    this.sessionService.createSession(patientId).pipe(
      takeUntil(this._unsubscriber)
    ).subscribe((res) => {
      this.session$.next(res.session);
      this.sessionId = res.session.id;
      if (!this.sessionId) {
        this.toast.presentToast('Error creating new session. Please try again.');
        this.routeToHome();
      }
    },
    (err) => {
      console.error(err);
      this.toast.presentToast('Error creating new session. Please try again.');
      this.routeToHome();
    });
  }

  public getComments() {
    this.comments$ = this.sessionService.getSessionComments(this.sessionId).pipe(
      map((res: GetCommentResponse) => {
        if (res.comments.length > 0) {
          setTimeout(() => {
            this.scrollToBottom();
          }, 1500);
        } else {
          this.showCommentDialog = true;
        }
        return res.comments;
      })
    );
  }

  // TODO: km - Tags should come back as array of tags;
  formatTags(tagString) {
    if (tagString && tagString.length) {
      return tagString.toLowerCase().split(';');
    } else {
      return [];
    }
  }

  viewDocument(document) {
    console.log('opening document');
    console.log(JSON.stringify(document));
    if (this.stateService.getPlatform() === 'web') {
      this.downloadFile(document, false, true);
    } else {
      console.log('DOCUMENT TO OPEN: ' + JSON.stringify(document));
      if (document.state === UIFileState.Exists) {
        return this.openFile(document);
      }
      this.downloadFile(document);
    }
  }

  private downloadFile(document, autoOpen = true, web = false) {
    console.log('DOWNLOADING FILE..');
    this.ngZone.run(() => {
      document.state = UIFileState.Downloading;
    });

    // this.sessionService.getDocumentDownloadUrl(document.id).pipe(takeUntil(this._unsubscriber))
    //   .subscribe((result) => {
    if (this.stateService.getPlatform() === 'web') {
      window.open(document.file_url, '_blank');
    } else {
      this.fileService.downloadUrl(document.file_url, document.file.filename, document.id, { autoOpen });
    }
      // });
  }

  public async openFile(document: any) {
    console.log('Opening file...');
    try {
      await this.fileService.openDownloadedFile(document.id, document.mime_type);
    } catch (e) {
      console.error(e);
      this.toast.presentToast('Failed to open file.');
    }
  }

  sortComments(comments: any, prop: string) {
    return comments.sort((a, b) => a[prop] > b[prop] ? 1 : a[prop] === b[prop] ? 0 : -1);
  }

  private fetchSessionData() {
    this.sessionService.getSessionData(this.sessionId).pipe(
      takeUntil(this._unsubscriber)
    ).subscribe((res) => {
      if (!res.session || !res.session.patient_id) {
        this.showLoadError();
      }
      this.fetchPatient(res.session.patient_id);
      this.sessionDate = moment(res.session.created_at).format('MMMM DD h:mm A');
      this.session$.next(res.session);
      this._sessionLikes = res.session.reaction_count;
      this.attachments = res.attachments;
      this.showAttachments = this.userService.isDoctor ? true : this.attachments.length !== 0 ? true : false;
      this.attachments$.next(res.attachments);
      this.isPublished = res.session.state === 'PUBLISHED' ? true : false;

      if (this._sessionLikes <= 0) {
        this.showLoveDialog = true;
      }
    }, (err) => {
      this.showLoadError();
    });
  }

  private fetchPatient(patientId) {
    this.patientService.getPatient(patientId).pipe(
      takeUntil(this._unsubscriber)
    ).subscribe((res) => {
      this.patientService.setCurrentPatient(res.patient);
      this.patient$ = res.patient;
    }, (err) => {
      this.showLoadError();
    });
  }

  private fetchAttachment(attachmentId: string, removeUploadIndex?: number | null) {
    this.sessionService.getSessionAttachment(this.sessionId, attachmentId).pipe(
      takeUntil(this._unsubscriber)
    ).subscribe((res) => {
      const foundIndex = this.attachments.findIndex(a => a.id === res.id);
      if (foundIndex > -1) {
        this.attachments.splice(foundIndex, 1);
      }
      if (typeof removeUploadIndex !== 'undefined' && removeUploadIndex > -1) {
        this.attachmentsUploading.splice(removeUploadIndex, 1);
        this.attachmentsUploading$.next(this.attachmentsUploading);
      }
      this.attachments.push(res);
      this.attachments$.next(this.attachments);
    });
  }

  async openAttachmentActionSheet(comment = false) {
    const mobileButtons = [
      {
        text: 'Take Photo',
        icon: 'camera',
        handler: () => {
          // this.startPhotoCapture();
          this.createSessionAttachment(ContentType.ImageCapture);
        }
      },
      {
        text: 'Take Video',
        icon: 'videocam',
        handler: () => {
          // this.startVideoCapture();
          this.createSessionAttachment(ContentType.VideoCapture);
        }
      },
      {
        text: 'Camera Roll',
        icon: 'image',
        handler: () => {
          // this.openPhotoLibrary();
          this.createSessionAttachment(ContentType.MediaSelection);
        }
      },
      {
        text: 'Cancel',
        role: 'cancel',
        handler: () => {
          console.log('Cancel clicked');
        }
      }
    ];
    const desktopButtons = [
      {
        text: 'Select Files',
        handler: () => {
          const input = comment ? 'comment' : 'session';
          this.triggerFileinput(input);
        }
      },
      {
        text: 'Cancel',
        role: 'cancel',
        handler: () => {
          console.log('Cancel clicked');
        }
      }
    ];

    const actionSheet = await this.actionCtrl.create({
      mode: 'ios',
      header: 'Add Attachments',
      subHeader: 'Please select one of the options below',
      cssClass: 'attachmentSheet',
      buttons: this.stateService.getPlatform() === 'web' ? desktopButtons : mobileButtons
    });
    await actionSheet.present();
  }

  async createSessionAttachment(contentType: ContentType) {
    console.log('CREATING SESSION ATTACHMENT.');
    let attachment = await this.uploadService.selectContent(contentType);
    if (contentType === ContentType.VideoCapture) {
        attachment = await this.formatAttachmentFromPlugin(attachment, PluginContentModel.MediaFile);
    }
    if (contentType === ContentType.ImageCapture) {
        attachment = await this.formatAttachmentFromPlugin(attachment, PluginContentModel.CameraPhoto);
    }
    console.log('ATTACHMENT: ' + JSON.stringify(attachment));
    this.uploadService.startContentUpload(attachment, UploadType.SessionAttachment, {sessionId: this.sessionId}).subscribe(
      (uploadObject: any) => {
        console.log('upload object from mobile: ' + JSON.stringify(uploadObject.attachmentObject));
        this.openTagModal(uploadObject.attachmentObject);
      }
    );
  }

  async startVideoCapture() {
    const options: CaptureVideoOptions = { limit: 1 };
    try {
      const videos: MediaFile[] | CaptureError = await this.mediaCapture.captureVideo(options);
      this.formatAttachmentFromPlugin(videos[0], 'MediaFile');
    } catch (err) {
      console.error(err);
      this.toast.presentToast('Upload failed, please try again!');
    }
  }

  async startPhotoCapture() {
    const image = await Camera.getPhoto({
      quality: 90,
      allowEditing: false,
      resultType: CameraResultType.Uri,
      source: CameraSource.Camera
    });
    this.formatAttachmentFromPlugin(image, 'CameraPhoto');
  }

  async _openPhotoLibrary(uploadType: UploadType) {
    const file: any = await this.mediaService.selectFromPhotoLibrary();
    // this.newComment.attachmentPath = file.path;
    const uploadSub = this.mediaService.uploadAttachmentObj.subscribe((uploadObject) => {
      switch (uploadType) {
        case UploadType.CommentAttachment:
          this.newComment.attachment = uploadObject.attachmentObject;
          this.newComment.attachmentPath = uploadObject.video.localFilePath;
          break;
        case UploadType.SessionAttachment:
          // Todo: kjm  finsihe upload by createing sessin attachmetn()?
          break;
      }
      uploadSub.unsubscribe();
    });
    this.mediaService.uploadMedia(file, uploadType, this.sessionId);
  }

  public async addCommentAttachment() {
    if (this.stateService.getPlatform() === 'web') {
      this.openAttachmentActionSheet(true);
    } else {
      const commentAttachment = await this.uploadService.selectContent(ContentType.MediaSelection);
      console.log('REG' + JSON.stringify(commentAttachment));
      this.uploading = true;
      this.isComment = true;
      this.uploadService.startContentUpload(commentAttachment, UploadType.CommentAttachment).subscribe(
        (uploadObject: any) => {
          console.log('UA:: ' + JSON.stringify(uploadObject));
          this.newComment.attachment = uploadObject.attachmentObject;
          this.newComment.attachmentPath = uploadObject.video.localFilePath;
          this.newComment.mimeType = uploadObject.video.mimeType;
          const uploadId = uploadObject.attachmentObject.uploadId;
          this.fileTransferService.uploadComplete$.subscribe((id) => {
            if (id && id === uploadId) {
              // upload complete
              console.log('upload complete registered from session: ' + id);

              if (this.newComment.text === '' && this.newComment.attachment === null) {
                setTimeout(() => {
                  this.getComments();
                  this.uploading = false;
                  this.isComment = false;
                  this.scrollToBottom(0);
                }, 2000);
              } else {
                this.uploading = false;
                this.isComment = false;
              }

            }
          });
          this.fileTransferService.uploadFailed$.subscribe((id) => {
            if (id && id === uploadId) {
              // upload complete
              console.log('upload failure registered from session: ' + id);
              this.uploading = false;
              this.isComment = false;

            }
          });
        },
        err => {
          this.uploading = false;
        }
      );
    }

  }

  async openPhotoLibrary() {
    let mediaFileToUpload = {};

    if (this.stateService.getPlatform() === 'ios') {
      const selectedMedia = await this.cordovaCam.getPicture({
        sourceType: this.cordovaCam.PictureSourceType.PHOTOLIBRARY,
        destinationType: this.cordovaCam.DestinationType.FILE_URI,
        mediaType: this.cordovaCam.MediaType.ALLMEDIA
      }).then((fileURI) => {
        return fileURI.indexOf('file://') === -1 ? `file://${fileURI}` : fileURI;
      });
      const pickedFile = selectedMedia;
      const resizedFile = pickedFile;
      const currentName = selectedMedia.substr(pickedFile.lastIndexOf('/') + 1);
      const resizedFileName = resizedFile.substr(resizedFile.lastIndexOf('/') + 1);
      mediaFileToUpload = {
        path: selectedMedia,
        thumbnailPath: selectedMedia,
        safeThumbnailPath: this.sanitizer.bypassSecurityTrustResourceUrl(selectedMedia),
        name: currentName,
        tags: [],
        category: 'Default',
      };
    } else if (this.stateService.getPlatform() === 'android') {
      const selectedMedia = await this.cordovaCam.getPicture({
        sourceType: this.cordovaCam.PictureSourceType.PHOTOLIBRARY,
        destinationType: this.cordovaCam.DestinationType.FILE_URI,
        mediaType: this.cordovaCam.MediaType.ALLMEDIA
      });
      const pickedFile = selectedMedia;
      const currentName = selectedMedia.substr(pickedFile.lastIndexOf('/') + 1);
      mediaFileToUpload = {
        path: selectedMedia,
        thumbnailPath: selectedMedia,
        safeThumbnailPath: this.sanitizer.bypassSecurityTrustResourceUrl(selectedMedia),
        name: currentName,
        tags: [],
        category: 'Default',
      };
    } else {
      // desktop implement file picker
    }
    this.uploadMedia(mediaFileToUpload);
    // this.openTagModal(mediaFileToUpload);
  }

  public handleFiles(event, comment = false) {
    this.uploading = true;
    console.log('handling file');
    const file = event.target.files[0];
    const mediaFileToUpload = {
      file,
      name: file.name,
      tags: [],
      category: 'Default',
    };

    // if (!comment) {
    const docUpload = this.documentService.uploadChange$
    .pipe(takeUntil(this._unsubscriber))
    .subscribe(upload => {
      if (upload && upload.state) {
        this.uploading = false;
      }
      switch (upload.state) {
        case FileUploadState.Start:
          // return this.handleUploadStart(upload);
        case FileUploadState.Progress:
          // return this.handleUploadProgress(upload);
        case FileUploadState.Success:
          docUpload.unsubscribe();
          return this.handleWebUploadSuccess(upload, comment);
        case FileUploadState.Error:
          // return this.handleUploadError(upload);
        default:
          break;
      }
    });
    this.documentService.uploadDocument(file, this.patientService.currentPatient.value.id);
    // } else {
      // const commentAttachment = file;
      // commentAttachment.path = file.name;
      // console.log('REG' + JSON.stringify(commentAttachment.path));
      // this.uploading = true;
      // this.uploadService.startContentUpload(commentAttachment, UploadType.CommentAttachment).subscribe(
      //   (uploadObject: any) => {
      //     this.newComment.attachment = uploadObject.attachmentObject;
      //     this.newComment.attachmentPath = uploadObject.video.localFilePath;
      //     this.newComment.mimeType = uploadObject.video.mimeType;
      //     const uploadId = uploadObject.attachmentObject.uploadId;
      //     this.uploading = false;

      //     this.fileTransferService.uploadComplete$.subscribe((id) => {
      //       if (id && id === uploadId) {
      //         // upload complete
      //         console.log('upload complete registered from session: ' + id);
      //         this.uploading = false;
      //       }
      //     });
      //     this.fileTransferService.uploadFailed$.subscribe((id) => {
      //       if (id && id === uploadId) {
      //         // upload complete
      //         console.log('upload failure registered from session: ' + id);
      //         this.uploading = false;
      //       }
      //     });
      //   },
      //   err => {
      //     this.uploading = false;
      //   }
      // );
    // }
    // this.uploadService.startContentUpload


    // this.uploadMedia(mediaFileToUpload);
  }

  triggerFileinput(id) {
    console.log(`hidden-input-${id}`);
    document.getElementById(`hidden-input-${id}`).click();
  }

  showUploadingToast() {
    this.toast.presentToast('"This file is still uploading. Depending on size, please check back in a few minutes."');
  }

  handleWebUploadSuccess(upload, comment) {
    console.log('upload: ' + JSON.stringify(upload));
    const webAttachment = this.uploadService.formatUploadObject(null, comment ? UploadType.CommentAttachment : UploadType.WebSessionAttachment, upload, {sessionId: this.sessionId});
    if (comment) {
      // this.uploading = true;
      // this.uploadService.startContentUpload(webAttachment, UploadType.CommentAttachment).subscribe(
      //   (uploadObject: any) => {
          this.newComment.attachment = webAttachment.attachmentObject;
          this.newComment.isWeb = true;
      //     this.newComment.attachmentPath = uploadObject.video.localFilePath;
          this.newComment.mimeType = webAttachment.video.mimeType;
      //     const uploadId = uploadObject.attachmentObject.uploadId;
      //     this.fileTransferService.uploadComplete$.subscribe((id) => {
      //       if (id && id === uploadId) {
      //         // upload complete
      //         console.log('upload complete registered from session: ' + id);
      //         this.uploading = false;
      //       }
      //     });
      //     this.fileTransferService.uploadFailed$.subscribe((id) => {
      //       if (id && id === uploadId) {
      //         // upload complete
      //         console.log('upload failure registered from session: ' + id);
      //         this.uploading = false;
      //       }
      //     });
      //   },
      //   err => {
      //     this.uploading = false;
      //   }
      // );
      // this.finishUploadByCreatingAttachment(webAttachment.attachmentObject, comment);
    } else {
      this.openTagModal(webAttachment.attachmentObject);
      console.log('handling success from web: ' + JSON.stringify(upload));
    }
  }

  async formatAttachmentFromPlugin(file, model) {
    let attachment: SessionAttachment;
    if (model === PluginContentModel.MediaFile) {
      console.log('FORMATTING MEDIAFILE');
      const base64Thumbnail = await this.extractThumbnails(file);
      attachment = {
        path: file.fullPath,
        thumbnailPath: base64Thumbnail,
        safeThumbnailPath: this.sanitizer.bypassSecurityTrustResourceUrl(file.fullPath),
        name: file.name,
        tags: [],
        category: 'Default',
      };
    } else if (model === PluginContentModel.CameraPhoto) {
      console.log('FORMATTING CAMERAPHOTO');
      attachment = {
        path: file.path,
        thumbnailPath: file.webPath,
        safeThumbnailPath: this.sanitizer.bypassSecurityTrustResourceUrl(file.webPath),
        tags: [],
        category: 'Default',
      };
    }
    return attachment;
  }

  extractThumbnails(file) {
    console.log('Extracting thumbnails');

    const thumbnl = PKVideoThumbnail.createThumbnail(
      file.localURL,
      'IGNORE',
      { mode: 'base64',
      quality: .8,
      position: 1.0,
      resize: {height: 384, width: 384} });

    return thumbnl.then((data) => {
      return data;
    });
  }

  async openTagModal(attachment) {
    const modal = await this.modalCtrl.create({
      component: SessionTagsComponent,
      componentProps: {
        thumbnailPath: attachment.safeThumbnailPath
      }
    });
    await modal.present();
    const { data } = await modal.onWillDismiss();
    attachment.session_sub_type = data.category;
    attachment.tags = data.tags;
    this.finishUploadByCreatingAttachment(attachment);
  }

  async openNotesModal(session) {
    const modal = await this.modalCtrl.create({
      component: SessionNotesComponent,
      componentProps: {
        session
      }
    });

    await modal.present();
    const { data } = await modal.onWillDismiss();
    session.coaching_focus_notes = data.coaching_focus_notes;
    session.session_update_notes = data.session_update_notes;
    this.session$.next(session);
    this.updateSession(data);
  }

  uploadMedia(attachment) {
    if ( this.stateService.getPlatform() === 'web') {
      // todo: - web upload

    } else {
      const videoResponse = this.sessionService.requestFileUploadPostUrl(attachment.path, 0, 0);

      const sessionAttachment = forkJoin([videoResponse]).pipe(
        map((s3response) => {
          const fileS3 = s3response[0];
          const sessionAttachmentObject = {
            video_file_id: fileS3.file.id,
            thumbnail_file_id: null,
            session_id: this.sessionId,
            session_sub_type: attachment.category,
            tags: attachment.tags,
            uploadId: null
          };
          return {
            uploadObject: {
              video: {
                localFilePath: attachment.path,
                uploadUrl: fileS3.uploadInfo.url,
                fileName: fileS3.file.filename,
                mimeType: fileS3.file.mime_type,
                fields: fileS3.uploadInfo.fields,
              },
              thumb: null
            },
            sessionAttachmentObject
          };
        })
      )
      .pipe(takeUntil(this._unsubscriber))
      .subscribe((val) => {
        const uploadId = this.fileTransferService.uploadFile(val.uploadObject.video, this.ngZone);
        val.sessionAttachmentObject.uploadId = uploadId;
        this.openTagModal(val.sessionAttachmentObject);
      }, (err) => {
        this.toast.presentToast('There was a problem uploading media, please try again');
      });
    }
  }

  async finishUploadByCreatingAttachment(uploadAttachment, comment = false) {
      console.log('UA' + JSON.stringify(uploadAttachment));
      this.sessionService.createSessionAttachment(this.sessionId, uploadAttachment)
      .pipe(takeUntil(this._unsubscriber))
      .subscribe((res) => {
        const foundIndex = this.uploadsFinished.indexOf(uploadAttachment.uploadId);
        if (foundIndex > -1) {
          this.fetchAttachment(res.id);
          this.uploadsFinished.splice(foundIndex, 1);
        } else {
          uploadAttachment.attachment_id = res.id;
          this.attachmentsUploading.push(uploadAttachment);
          this.attachmentsUploading$.next(this.attachmentsUploading);
        }
      }, (err) => {
        this.toast.presentToast('Session attachment creation failed.');
      });
  }

  updateSession(data) {
    this.sessionService.updateSession(this.session).pipe(takeUntil(this._unsubscriber)).subscribe((res) => {
      res.session.creator_name = data.creator_name;
      res.session.organization_name = data.organization_name;
      this.session$.next(res.session);
    });
  }

  publishSession() {
    this.sessionService.publishSession(this.sessionId).pipe(
      takeUntil(this._unsubscriber)
    ).subscribe((publishedRes: any) => {
      this.session$.next(publishedRes.session);
      this.showCompleteModal();
      this.isPublished = true;
      this.toast.presentToast('Rock on, your post was successfully uploaded.');
    }, (err) => {
      this.toast.presentToast('Post Being Viewed  creation failed, please retry.');
    });
  }

  async showCompleteModal() {
    const modal = await this.modalCtrl.create({
      component: SessionCompleteComponent
    });
    await modal.present();

    await modal.onWillDismiss();
    this.routeToHome();
  }

  async playVideo(video, commentId) {
    const modal = await this.modalCtrl.create({
        component: LoadingContentComponent
      });
    await modal.present();

    const playCountEndpoint = (!!commentId) ?
                              this.sessionService.getSessionCommentVideoPlayUrl(this.sessionId, commentId, video.id) :
                              this.sessionService.getSessionVideoPlayUrl(this.sessionId, video.id);

    playCountEndpoint.pipe(
      takeUntil(this._unsubscriber)
    ).subscribe(async (videoUrl) => {
      if (this.stateService.getPlatform() === 'ios' || this.stateService.getPlatform() === 'android') {
        const videoPlayer = CapacitorVideoPlayer;
        this.isPlayingVideo(video.file_url, videoPlayer, modal);
      } else {
        modal.dismiss();
        const webVideoModal = await this.modalCtrl.create({
          component: WebVideoComponent,
          componentProps: {
            video
          }
        });
        await webVideoModal.present();
      }
    }, err => {
      modal.dismiss();
      if (err.status === 404) {
        this.toast.presentToast('The video you are trying to view is no longer available.');
      }
    });
  }

  isPlayingVideo(video, videoPlayer, modal) {
    setTimeout(async () => {
      modal.dismiss();
      await videoPlayer.initPlayer({mode: 'fullscreen', url: video, playerId: 'player-id', componentTag: 'app-session'});
    }, 1000);
  }

  postComment() {
    const commentData = {
      session_id: this.sessionId,
      content: this.newComment.text.length > 0 ? this.newComment.text : ' ',
      attachments: [this.newComment.attachment]
    };
    this.sessionService.postSessionComment(commentData).pipe(
      takeUntil(this._unsubscriber)
    ).subscribe((res: GetCommentResponse) => {
      this.resetComment();
      this.getComments();
      setTimeout(() => {
        this.scrollToBottom();
      }, 1500);
    }, (err) => {
      console.log(err);
      this.toast.presentToast('comment failed to post please retry.');
    });
  }

  resetComment() {
    this.newComment.text = '';
    this.newComment.attachmentPath = null;
    this.newComment.attachment = null;
    this.newComment.mimeType = null;
    this.newComment.isWeb = false;
  }

  get sessionLikes(): number | string {
    return this._sessionLikes;
  }


  like() {
    this.sessionService.postSessionReaction(this.session.id).pipe(
      takeUntil(this._unsubscriber)
    ).subscribe((val) => {
      const currCount = this._sessionLikes;
      const newCount = parseInt(currCount, 10) + 1;
      this._sessionLikes = newCount;
      this.toast.presentToast('Way to show the love! You can add as many as you like.');
    });
  }

  goToSettings() {
    this.nav.navigateForward([`settings/child/${this.patient$.id}`]);
  }

  async imageClicked(url) {
    if (this.plt.is('cordova')) {
      this.photoViewer.show(url);
    } else {
      const modal = await this.modalCtrl.create({
        component: SessionViewAttachmentComponent,
        componentProps: {
          link: url
        }
      });
      await modal.present();
    }
  }

  scrollToBottom(duration = 1500) {
    this.content.scrollToBottom(duration);
  }

  closeLoveDialog() {
    this.showLoveDialog = false;
  }

  closeCommentDialog() {
    this.showCommentDialog = false;
  }

}
