import { Component, OnInit } from '@angular/core';
import { FormGroup, FormBuilder, Validators } from '@angular/forms';
import { UserService } from 'src/app/services/user.service';
import { SpecialtyService } from 'src/app/services/specialty.service';
import { map } from 'rxjs/operators';
import { ToastService } from '../../../services/toast.service';
import { User } from 'src/app/models/Client';
import { NavController } from '@ionic/angular';

@Component({
  selector: 'app-add-network',
  templateUrl: './add-network.component.html',
  styleUrls: ['./add-network.component.scss'],
})
export class AddNetworkComponent implements OnInit {
  public pageTitle;
  public addTherapyProviderForm: FormGroup;
  public specialties$;
  public user: User;

  constructor(
    private fb: FormBuilder,
    public userService: UserService,
    private specialtyService: SpecialtyService,
    private toastService: ToastService,
    private nav: NavController
  ) { }

  ngOnInit() {
    this.pageTitle = 'Add Therapist';
    this.addTherapyProviderForm = this.fb.group({
      therapyOrganizationName: ['', Validators.required],
      city: ['', Validators.required],
      therapistFirstName: ['', Validators.required],
      therapistLastName: ['', Validators.required],
      therapistEmail: ['',
        Validators.compose([Validators.maxLength(70),
          Validators.email,
          Validators.required])]
    });

    this.specialties$ = this.specialtyService.getSpecialties().pipe(
      map(val => val.specialties)
    );
  }

  saveTherapist() {
    this.userService.addNetwork(this.addTherapyProviderForm.value).subscribe((val) => {
      this.toastService.presentToast('Thank you! This account will be added in 24 hours.');
      setTimeout(() => {
        this.routeToHome();
      }, 2000);
    }, (err) => {
      this.toastService.presentToastTopWithClose(`Error adding therapy provider. Please try again or contact support.`);
      console.log(JSON.stringify(err));
    });
  }

  routeToHome() {
    if (this.userService.isDoctor) {
      this.nav.navigateForward([`/patients`]);
    } else {
      this.nav.navigateRoot(`/timeline`);
    }
  }

}
