import { Component, OnInit } from '@angular/core';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { UserService } from 'src/app/services/user.service';
import { ToastService } from '../../../services/toast.service';
import { NavController } from '@ionic/angular';

@Component({
  selector: 'app-add-therapist',
  templateUrl: './add-therapist.component.html',
  styleUrls: ['./add-therapist.component.scss'],
})
export class AddTherapistComponent implements OnInit {
  public addNewTherapyProviderForm: FormGroup;

  constructor(
    private fb: FormBuilder,
    public userService: UserService,
    private toastService: ToastService,
    private nav: NavController,
  ) { }

  ngOnInit() {
    this.addNewTherapyProviderForm = this.fb.group({
      firstName: ['', Validators.required],
      lastName: ['', Validators.required],
      email: ['',
        Validators.compose([Validators.maxLength(70),
          Validators.email,
          Validators.required])]
    });
  }

  submit() {
    const data = {
      email: this.addNewTherapyProviderForm.value.email,
      firstName: this.addNewTherapyProviderForm.value.firstName,
      lastName: this.addNewTherapyProviderForm.value.lastName,
    };

    this.userService.addTherapist(data).subscribe(() => {
      this.toastService.presentToast(`New therapy provider invite successful.`);
      setTimeout(() => {
        this.nav.back();
      }, 1000);
    }, (err) => {
      this.toastService.presentToastTopWithClose(`Error inviting new therapy provider. Please try again or contact support.`);
      console.log(JSON.stringify(err));
    });
  }

}
