import { Component, OnInit } from '@angular/core';
import { MenuItem } from 'src/app/models/client/menuitem';
import { UserService } from 'src/app/services/user.service';
import { PatientService } from 'src/app/services/patient.service';
import { StateService } from 'src/app/services/state.service';
import { ActivatedRoute, ParamMap } from '@angular/router';
import { ActionSheetController } from '@ionic/angular';
import { Camera as CordovaCamera } from '@ionic-native/camera/ngx';
import { Plugins, CameraResultType, CameraSource } from '@capacitor/core';
const { Device, Camera } = Plugins;
import { DomSanitizer } from '@angular/platform-browser';
import { User } from 'src/app/models/Client';
import { ToastService } from 'src/app/services/toast.service';
import { FormGroup, FormControl, FormBuilder, Validators } from '@angular/forms';

@Component({
  selector: 'app-child',
  templateUrl: './child.component.html',
  styleUrls: ['./child.component.scss'],
})
export class ChildComponent implements OnInit {
  public pageTitle = this.userService.isGuardian ? 'My Child' : 'Child';
  public userMenu: MenuItem[];
  public patient;
  public attachmentLoading = false;
  public user: User;
  public childForm: FormGroup;
  childsName;
  dob;
  notes;

  constructor(
    public userService: UserService,
    private patientService: PatientService,
    private route: ActivatedRoute,
    private actionCtrl: ActionSheetController,
    private cordovaCam: CordovaCamera,
    private stateService: StateService,
    private toast: ToastService,
    private fb: FormBuilder,
    ) { }

  ngOnInit() {
    this.childForm = this.fb.group({
      dob: ['', Validators.required],
      notes: ['', Validators.required]
    });

    this.route.paramMap.subscribe((params: ParamMap) => {
      const patientId = params.get('child_id');
      this.patientService.getPatient(patientId).subscribe((res) => {
        this.patient = res.patient;
        this.childsName = res.patient.first_name + ' ' + res.patient.last_name;
        this.dob = res.patient.date_of_birth;
        this.notes = res.patient.notes;
        console.log('patient', res.patient);
      });
    });
  }

  async openAttachmentActionSheet() {
    const actionSheet = await this.actionCtrl.create({
      mode: 'ios',
      header: 'Add Profile Pic',
      subHeader: 'Please select one of the options below',
      cssClass: 'attachmentSheet',
      buttons: [
        {
          text: 'Take Photo',
          icon: 'camera',
          handler: () => {
            this.startPhotoCapture();
          }
        },
        {
          text: 'Camera Roll',
          icon: 'image',
          handler: () => {
            this.openPhotoLibrary();
          }
        },
        {
          text: 'Cancel',
          role: 'cancel',
          handler: () => {
            console.log('Cancel clicked');
          }
        }
      ]
    });
    await actionSheet.present();
  }

  addProfilePic(file: any, model: any) {
    console.log('ADDING PROFILE PIC', file, model);
    // Temporary Dislpay of Profile Pic
    this.user.picture = file.thumbnailPath;

    // let attachment: SessionAttachment;
    // if (model === 'MediaFile') {
    //   attachment = {
    //     path: this.sanitizer.bypassSecurityTrustResourceUrl(file.fullPath),
    //     mediaType: file.type,
    //     localUrl: file.localUrl,
    //     thumbnailPath: this.sanitizer.bypassSecurityTrustResourceUrl(file.fullPath),
    //     name: file.name,
    //     tags: [],
    //     isSelected: false,
    //     category: 'Default'
    //   };
    // } else if (model === 'CameraPhoto') {
    //   attachment = {
    //     path: this.sanitizer.bypassSecurityTrustResourceUrl(file.path),
    //     mediaType: 'Image',
    //     format: file.format,
    //     localUrl: file.webPath,
    //     thumbnailPath: this.sanitizer.bypassSecurityTrustResourceUrl(file.webPath),
    //     tags: [],
    //     isSelected: false,
    //     category: 'Default'
    //   };
    // }
    // this.openTagModal(attachment);

    this.attachmentLoading = true;
  }

  async startPhotoCapture() {
    const image = await Camera.getPhoto({
      quality: 90,
      allowEditing: false,
      resultType: CameraResultType.Uri,
      source: CameraSource.Camera
    });
    this.addProfilePic(image, 'CameraPhoto');
  }

  async openPhotoLibrary() {
    const info = await Device.getInfo();
    let mediaFileToUpload = {};
    if (this.stateService.getPlatform() === 'ios' || this.stateService.getPlatform() === 'android') {
      const selectedMedia = await this.cordovaCam.getPicture({
        sourceType: this.cordovaCam.PictureSourceType.PHOTOLIBRARY,
        destinationType: this.cordovaCam.DestinationType.FILE_URI,
        mediaType: this.cordovaCam.MediaType.ALLMEDIA
      });
      const pickedFile = selectedMedia;
      const resizedFile = pickedFile;
      const currentName = selectedMedia.substr(pickedFile.lastIndexOf('/') + 1);
      const resizedFileName = resizedFile.substr(resizedFile.lastIndexOf('/') + 1);
      mediaFileToUpload = {
        // sessionId: this.sessionId,
        videoName: currentName,
        thumbnailName: resizedFileName,
        videoPath: selectedMedia,
        thumbnailPath: selectedMedia,
        fullThumbnailPath: selectedMedia,
        duration: 0,
        videoType: undefined,
        createdAt: new Date(),
        updatedAt: new Date(),
        tags: [],
        isImage: false
      };
      console.log('CREATED FILE OBJ', mediaFileToUpload);
      this.addProfilePic(mediaFileToUpload, 'MediaFile');
    } else {
      // desktop implement file picker
    }
    // this.openTagModal(mediaFileToUpload);
  }

  public updateDateOfBirth(patientId, val) {
    this.patientService.updateDateOfBirth(patientId, val).subscribe((res) => {
      console.log('dob: ', res);
    });
  }

  public updateNotes(patientId, val) {
    this.patientService.updateNotes(patientId, val).subscribe((res) => {
      console.log('notes: ', res);
    });
  }

  save(patientId) {
    const dob = this.childForm.get('dob').value;
    const notes = this.childForm.get('notes').value;

    this.updateDateOfBirth(patientId, dob);
    this.updateNotes(patientId, notes);
    this.toast.presentToast('Saved!');
  }

}
