import { Component, OnInit } from '@angular/core';
import { UserService } from 'src/app/services/user.service';
import { AuthService } from 'src/app/services/auth.service';
import { NavController, Platform } from '@ionic/angular';
import { MenuItem } from 'src/app/models/client/menuitem';
import { Patient } from 'src/app/models/Server';
import { PatientService } from 'src/app/services/patient.service';
import { EmailComposer } from '@ionic-native/email-composer/ngx';

@Component({
  selector: 'app-settings',
  templateUrl: './settings.component.html',
  styleUrls: ['./settings.component.scss'],
})
export class SettingsComponent implements OnInit {
  public pageTitle = 'Settings';
  public user;
  public menuItems: MenuItem[];
  public patientId;
  constructor(
    public userService: UserService,
    private authService: AuthService,
    private nav: NavController,
    private patientService: PatientService,
    private emailComposer: EmailComposer,
    private plt: Platform,
    ) { }

  ngOnInit() {
    this.user = this.userService.user;

    this.patientService.currentPatient.subscribe((child: Patient) => {
      this.patientId = child.id;
      this.setMenu();
    });
  }

  setMenu() {
    if (this.userService.isDoctor) {
      this.menuItems = [
        {
          title: 'Account Info',
          icon: 'contact',
          route: 'account'
        },
        {
          title: 'Organization',
          icon: 'business',
          route: 'organization'
        },
        {
          title: 'Customer Support',
          icon: 'help-buoy',
          action: 'customerSupport'
        },
        {
          title: 'Logout',
          icon: 'power',
          action: 'logout'
        }
      ];
    } else {
      this.menuItems = [
        {
          title: 'My Child',
          icon: 'egg',
          route: `child/${this.patientId}`
        },
        {
          title: 'My Account',
          icon: 'contacts',
          route: 'account'
        },
        {
          title: 'Caregiver Team',
          icon: 'business',
          route: 'caregivers'
        },
        {
          title: 'My Therapy Providers',
          icon: 'notifications-outline',
          route: 'network'
        },
        {
          title: 'Customer Support',
          icon: 'help-buoy',
          action: 'customerSupport'
        },
        {
          title: 'Logout',
          icon: 'power',
          action: 'logout'
        }
      ];
    }
  }

  async isAction(action: any) {
    if (action === 'customerSupport') { this.customerSupportClicked(); }
    if (action === 'logout') { this.logoutClicked(); }
  }


  private async logoutClicked() {
    await this.authService.invalidate();
    this.nav.navigateRoot(['auth']);
  }

  private async customerSupportClicked() {
    if (this.plt.is('cordova')) {
      const email = {
        to: 'support@theraweconnect.com',
        cc: '',
        bcc: [],
        attachments: [],
        subject: '',
        body: '',
        isHtml: true
      };

      this.emailComposer.open(email);
    } else {
      window.open('mailto:support@theraweconnect.com');
    }
  }


}
