import {Component, OnInit, ViewChild, ElementRef, NgZone, Renderer2, RendererFactory2, Inject} from '@angular/core';
import { Unsubscriber } from '../common/unsubscriber';
import { CommunicationService } from 'src/app/services/communication.service';
import { ToastService } from 'src/app/services/toast.service';
import { Platform, NavController } from '@ionic/angular';
import { StateService } from 'src/app/services/state.service';
// import { Html2canvasService } from 'src/app/services/html2canvas.service';
import { UserService } from 'src/app/services/user.service';
import { TwilioService } from 'src/app/services/twilio.service';
import { PatientService } from 'src/app/services/patient.service';
import { SocketsService } from 'src/app/services/sockets.service';
declare var twiliovideo: any;
import {createWriteStream} from 'fs' ;
import { HttpClient } from '@angular/common/http';
import { connect, createLocalTracks, createLocalVideoTrack, LocalVideoTrack } from 'twilio-video';
import { NgxSpinnerService } from 'ngx-spinner';
import { AudioService } from 'src/app/services/audio.service';
import {switchMap} from 'rxjs/operators';
import {ActivatedRoute, ParamMap, Params, Router} from '@angular/router';
import { MenuController } from '@ionic/angular';

import html2canvas from 'html2canvas';
import {Session} from '../../models/server/Session';
import {SessionService} from '../../services/session.service';
import {browser} from 'protractor';
import {User} from '../../models/Client';
const TinyURL = require('tinyurl');
import domtoimage from 'dom-to-image';

export enum TwilioEvent {
    Connected = 'CONNECTED',
    Closed = 'CLOSED',
    Muted = 'MUTED',
    Unmuted = 'UNMUTED',
}

declare let cordova: any;


@Component({
    selector: 'app-video',
    templateUrl: './video.component.html',
    styleUrls: ['./video.component.scss'],
})
export class VideoComponent extends Unsubscriber implements OnInit {

    constructor(
        private toastService: ToastService,
        private sessionService: SessionService,
        private plt: Platform,
        public stateService: StateService,
        private communicationService: CommunicationService,
        public userService: UserService,
        public twilioService: TwilioService,
        private nav: NavController,
        private spinner: NgxSpinnerService,
        private audio: AudioService,
        public ngZone: NgZone,
        private route: ActivatedRoute,
        private router: Router,
        private socketsService: SocketsService,
        private patientService: PatientService,
        private http: HttpClient,
        // private html2canvasService: Html2canvasService,
        private rendererFactory: RendererFactory2,
        public menu: MenuController,
        // @Inject(DOCUMENT) private document: Document,
    ) {
        super();
        this.twilioService.msgSubject.subscribe(r => {
            this.messages.push(r);
        });

        this.route.paramMap.subscribe((params: Params) => {
            this.token = params.get('token');
            this.roomName = params.get('roomName');
            if (this.token) {
                this.communicationService.setIncomingCall({
                    token: this.token,
                    roomName: this.roomName,
                });
                this.joinWebCall(this.communicationService.incomingCallInfo);
                console.log('video component params');
                console.log(this.token);
                console.log(this.roomName);
            }
        });

        this.renderer = rendererFactory.createRenderer(null, null);
        this.captures = [];
    }
    get videoCanvas(): HTMLCanvasElement {
        return this.videoCanvasRef.nativeElement;
    }
    @ViewChild('mainVideoBody') mainVideoBody: ElementRef;
    // @ViewChild('videoCanvas') videoCanvas: ElementRef;
    @ViewChild('localVideo') localVideo: ElementRef;
    @ViewChild('remoteVideoSmall') remoteVideoSmall: ElementRef;
    @ViewChild('remoteVideo1') remoteVideo1: ElementRef;
    @ViewChild('remoteVideo2') remoteVideo2: ElementRef;
    @ViewChild('remoteVideo3') remoteVideo3: ElementRef;
    @ViewChild('remoteVideo4') remoteVideo4: ElementRef;
    @ViewChild('remoteVideo5') remoteVideo5: ElementRef;
    @ViewChild('remoteVideo6') remoteVideo6: ElementRef;
    @ViewChild('remoteVideo7') remoteVideo7: ElementRef;
    @ViewChild('remoteVideo8') remoteVideo8: ElementRef;
    @ViewChild('remoteVideo9') remoteVideo9: ElementRef;
    @ViewChild('remoteVideo10') remoteVideo10: ElementRef;

    @ViewChild('leaveRoom') leaveRoom: ElementRef;
    @ViewChild('roomDiv') roomDiv: ElementRef;
    @ViewChild('mainParticipant1') mainParticipant1: ElementRef;
    @ViewChild('mainParticipant2') mainParticipant2: ElementRef;
    @ViewChild('mainParticipant3') mainParticipant3: ElementRef;
    @ViewChild('mainParticipant4') mainParticipant4: ElementRef;
    @ViewChild('mainParticipant5') mainParticipant5: ElementRef;
    @ViewChild('mainParticipant6') mainParticipant6: ElementRef;
    @ViewChild('mainParticipant7') mainParticipant7: ElementRef;
    @ViewChild('mainParticipant8') mainParticipant8: ElementRef;
    @ViewChild('mainParticipant9') mainParticipant9: ElementRef;
    @ViewChild('mainParticipant10') mainParticipant10: ElementRef;
    @ViewChild('participant1Div') participant1Div: ElementRef;
    @ViewChild('participant2Div') participant2Div: ElementRef;
    @ViewChild('participant3Div') participant3Div: ElementRef;
    @ViewChild('participant4Div') participant4Div: ElementRef;
    @ViewChild('participant5Div') participant5Div: ElementRef;
    @ViewChild('participant6Div') participant6Div: ElementRef;
    @ViewChild('participant7Div') participant7Div: ElementRef;
    @ViewChild('participant8Div') participant8Div: ElementRef;
    @ViewChild('participant9Div') participant9Div: ElementRef;
    @ViewChild('participant10Div') participant10Div: ElementRef;
    @ViewChild('activeParticipant1Video') activeParticipant1Video: ElementRef;
    @ViewChild('activeParticipant2Video') activeParticipant2Video: ElementRef;
    @ViewChild('activeParticipant3Video') activeParticipant3Video: ElementRef;
    @ViewChild('activeParticipant4Video') activeParticipant4Video: ElementRef;
    @ViewChild('activeParticipant5Video') activeParticipant5Video: ElementRef;
    @ViewChild('activeParticipant6Video') activeParticipant6Video: ElementRef;
    @ViewChild('activeParticipant7Video') activeParticipant7Video: ElementRef;
    @ViewChild('activeParticipant8Video') activeParticipant8Video: ElementRef;
    @ViewChild('activeParticipant9Video') activeParticipant9Video: ElementRef;
    @ViewChild('activeParticipant10Video') activeParticipant10Video: ElementRef;
    // @ViewChild('remoteVideo3') remoteVideo3: ElementRef;
    @ViewChild('snapshot') snapshot: ElementRef;
    // ctx: CanvasRenderingContext2D;
    public isUnavailable = false;
    public platform;
    public accessToken;
    public newToken;
    private routeSub;
    public token: string;
    public recipientsArray: Array<any> = [];
    public contacts: Array<any> = [];
    public roomName: string;
    message: string;
    messages: Array<any> = ['<span class="bold"><img src="assets/icon/TW-Icon_Blue_RGB-01.svg" class="videoMessagesIcon">Video Messages</span>'];
    private backgroundModal: HTMLIonModalElement;
    private renderRef: any;
    private renderer: Renderer2;
    public showNextButton = false;
    private img: any;
    public caller: User;
    public callee: User;
    private canvas: HTMLCanvasElement;
    private context: CanvasRenderingContext2D;
    isMuted: any;
    captures: Array<any>;

    @ViewChild('videoCanvas') videoCanvasRef: ElementRef;

    ngOnInit() {
        this.spinner.show();
        this.audio.preload('play', 'assets/sounds/videocall.mp3');
        this.platform = this.stateService.getPlatform();

        this.twilioService.localVideo = this.localVideo;
        this.twilioService.remoteVideoSmall = this.remoteVideoSmall;
        this.twilioService.remoteVideo1 = this.remoteVideo1;
        this.twilioService.leaveRoom = this.leaveRoom;
        this.twilioService.roomDiv = this.roomDiv;


        if (
            this.communicationService.startNewCall &&
            !!this.communicationService.recipientIds &&
            this.communicationService.recipientIds.length > 0
        ) {
            this.caller = this.userService.user;
            this.startNewVideoCall();
            this.communicationService.startNewCall = false;
            console.log('this.recipientsArray');
            console.log(this.recipientsArray);
            this.getRecipients();
            this.getContacts();
        } else if (this.communicationService.incomingCall && !!this.communicationService.incomingCallInfo) {
            this.callee = this.userService.user;
            this.joinIncomingCall();
            this.communicationService.incomingCall = false;
            console.log('this.recipientsArray');
            console.log(this.recipientsArray);
            this.getRecipients();
            this.getContacts();
        }
    }

    capture() {
        console.log('this.mainVideoBody.nativeElement');
        console.log(this.mainVideoBody.nativeElement);
        const node = document.getElementById('mainIonVideoContent');
        const cln = document.getElementById('local').cloneNode(true);
        document.getElementById('mainIonVideoContent').appendChild(cln);
        const cln2 = document.getElementById('remote1').cloneNode(true);
        document.getElementById('mainIonVideoContent').appendChild(cln2);
        domtoimage.toJpeg(document.getElementById('mainIonVideoContent'), { quality: 0.95 })
            .then(dataUrl => {
                const linkCapture = document.createElement('a');
                linkCapture.download = 'my-image-name-main.jpeg';
                linkCapture.href = dataUrl;
                linkCapture.click();
            });
    }

    saveCaptureAs(uri, filename) {
        const newLink = document.createElement('a');
        if (typeof newLink.download === 'string') {
            newLink.href = uri;
            newLink.download = filename;

            // Firefox requires the link to be in the body
            document.body.appendChild(newLink);

            // simulate click
            newLink.click();

            // remove the link when done
            document.body.removeChild(newLink);
        } else {
            window.open(uri);
        }
    }

    getContacts() {
        this.communicationService.getContacts().subscribe((res) => {
            console.log('getContacts res');
            console.log(res);
            this.contacts = res;
        });
    }

    async getFilteredRecipients(ev: any) {
        this.contacts = await this.communicationService.getContacts().toPromise();

        const val = ev.target.value;

        if (val && val.trim() !== '') {
            this.contacts = this.contacts.filter((recipient) => {
                console.log('recipient');
                console.log(recipient);
                const recipientFullName = recipient.first_name + ' ' + recipient.last_name;
                return (recipientFullName.toLowerCase().indexOf(val.toLowerCase()) > -1);
            });
        }
    }

    async getFilteredRecipientsByType(userType: any) {
        this.contacts = await this.communicationService.getContacts().toPromise();
        this.contacts = this.contacts.filter((recipient) => {
            const isDoctor = recipient.is_doctor;
            return ((userType === 'parents' && isDoctor === false) || (userType !== 'parents' && isDoctor === true));
        });
    }

    btnActivate(ionicButton) {
        ionicButton.color =  'primary';
    }

    btnDeactivate(ionicButton) {
        ionicButton.color =  'grey-xl';
    }

    inviteMoreVideoParticipants() {
        // update this.communicationService.recipientIds with new invitees
        const inviteMoreselectedContactIds = this.contacts.filter(c => c.isSelected).map(c => c.user_id);
        this.communicationService.createNewCall(inviteMoreselectedContactIds);
        // this.nav.navigateForward(`/video`);
        // push new invitees into this.recipientsArray
        // call this.startNewVideoCall() but use existing roomname and SID
        this.toastService.presentToast('Invites have been sent!');
        this.toggleViewersSideBar();
        this.startNewVideoCall();
    }

    getRecipients() {
        this.communicationService.getContacts().subscribe((res) => {
            res.forEach(c => {
                console.log(c);
                if (this.communicationService.recipientIds.includes(c.user_id)) {
                this.recipientsArray.push(c);
                console.log('this.recipientsArray');
                console.log(this.recipientsArray);
            }});
        });
    }

    onChange() {
        const selectedContactIds = this.contacts.filter(c => c.isSelected).map(c => c.user_id);
        // if (selectedContactIds.length > 1 || selectedContactIds.length < 1) {
        //   this.showNextButton = false;
        // if (selectedContactIds.length > 1) {
        //   this.toast.presentToast('Please select only one person to video call. Multiple people in a room is coming in May!');
        // }
        // } else {
        this.showNextButton = true;
        // }
    }

    showInviteRecipents() {
        document.getElementById('inviteRecipients').style.display = 'inline-block';
        document.getElementById('viewersDetails').style.display = 'none';
    }

    showViewerDetails() {
        document.getElementById('viewersDetails').style.display = 'inline-block';
        document.getElementById('inviteRecipients').style.display = 'none';
    }

    toggleViewersSideBar() {
        const els = document.getElementsByClassName('rounded-video-box-corners');
        console.log('document.getElementById(\'viewersSideBar\').style.width');
        console.log(document.getElementById('viewersSideBar').style.width);
        if (document.getElementById('viewersSideBar').style.width !== '250px') {
            document.getElementById('viewersSideBar').style.width = '250px';
            Array.from(els).forEach((el) => {
                document.getElementById(el.id).style.right = '250px';
            });
        } else {
            document.getElementById('viewersSideBar').style.width = '0px';
            Array.from(els).forEach((el) => {
                document.getElementById(el.id).style.right = '0px';
            });
        }
    }

    copyInputMessage(inputElement) {
        inputElement.select();
        document.execCommand('copy');
        inputElement.setSelectionRange(0, 0);
    }

    async getComposition() {
        this.communicationService.getComposition().subscribe(async res => {
            console.log('getComposition res');
            console.log(res);
        });
    }

    async startNewVideoCall() {
        if (this.plt.is('cordova')) {
            this.communicationService.startVideoCall().subscribe(async res => {
                // videoCallers.push()
                this.audio.play('play');
                console.log('res inside StartNewVideoCall');
                console.log(res);
                this.startCall(res);
            });
        } else {
            this.communicationService.startVideoCall().subscribe(async res => {
                // videoCallers.push()
                this.audio.play('play');
                // this.socketsService.playRing();
                console.log('res inside StartNewVideoCall');
                this.startWebCall(res);
            });
        }
    }

    public async joinIncomingCall() {
        if (this.stateService.getPlatform() === 'web') {
            this.joinWebCall(this.communicationService.incomingCallInfo);
        } else {
            this.startCall(this.communicationService.incomingCallInfo);
        }
    }

    disconnectCall() {
        const cordovaCall = (cordova.plugins as any).CordovaCall;
        cordovaCall.endCall(() => {
            console.log(`End call success`);
        }, () => {
            console.log(`End call error`);
        });
        this.routeOnClose();
    }

    Mute() {
        const cordovaCall = (cordova.plugins as any).CordovaCall;
        cordovaCall.mute(() => {
            console.log(`Mute success`);
        }, () => {
            console.log(`Mute error`);
        });
        this.routeOnClose();
    }

    routeOnClose() {
        if (this.userService.isDoctor) {
            console.log('doctor');
            // this.nav.navigateRoot('');
            this.nav.navigateRoot(`/recipients`);
        } else {
            this.nav.navigateRoot(`/timeline`);
        }

        if (!!this.backgroundModal) {
            this.backgroundModal.dismiss();
        }
    }

    /********* FUNCTIONS FOR MOBILE *********/
    async startCall(callInfo) {
        if (!callInfo.token || !callInfo.roomName) {
            this.toastService.presentToast('Could not join call');
            this.nav.navigateForward([`/recipients`]);
        }
        console.log(callInfo);

        const TwilioVideo = twiliovideo;
        const hasPermission = await TwilioVideo.requestPermissions();
        if (hasPermission) {
            await TwilioVideo.openRoom(
                callInfo.token,
                callInfo.roomName,
                (evt, data) => {
                    console.log(`Video event: ${evt} -- ${data}`);
                    const cordovaCall = (cordova.plugins as any).CordovaCall;
                    switch (evt) {
                        case TwilioEvent.Connected:
                            this.audio.pause('play');
                            this.spinner.hide();
                            break;
                        case TwilioEvent.Closed:
                            this.disconnectCall();
                            break;
                        case TwilioEvent.Muted:
                            cordovaCall.mute(() => {
                                console.log(`Mute success`);
                            }, (err) => {
                                console.log(`Mute error: ${JSON.stringify(err)}`);
                            });
                            break;
                        case TwilioEvent.Unmuted:
                            cordovaCall.unmute(() => {
                                console.log(`Unmute success`);
                            }, (err) => {
                                console.log(`Unmute error: ${JSON.stringify(err)}`);
                            });
                            break;
                    }
                },
                {
                    primaryColor: '#F0767A',
                    secondaryColor: '#247ba0'
                }
            );
        } else {
            this.toastService.presentToast('Must accept permissions to video call');
        }
    }


    /********* FUNCTIONS FOR WEB *********/

    async startWebCall(res) {
        if (!res.token || !res.roomName) {
            // this.toastService.presentToast('Could not join call');
            this.nav.navigateForward([`/recipients`]);
        }

        // console.log(res);
        this.accessToken = res.accessToken;
        this.twilioService.connectToRoom(res.token, { name: res.roomName, audio: true, video: { height: 720, frameRate: 24, width: 1280 },
            logLevel: 'debug',
            bandwidthProfile: {
                video: {
                    mode: 'grid',
                    maxTracks: 10,
                    renderDimensions: {
                        high: {height: 1080, width: 1980},
                        standard: {height: 1080, width: 1980},
                        low: {height: 1080, width: 1980}
                    }
                }
            },
            maxAudioBitrate: 16000,
            preferredVideoCodecs: [{ codec: 'VP8', simulcast: true }],
            networkQuality: {local: 1, remote: 1} });

        const url_string = window.location.href;
        const meetingLink = document.getElementById('meetingLink') as HTMLInputElement;
        const longURL = window.location.origin + '/video/' + res.token + '/' + res.roomName;
    }

    async joinWebCall(res) {
        if (!res.token || !res.roomName) {
            // this.toastService.presentToast('Could not join call');
            this.nav.navigateForward([`/recipients`]);
        }

        this.accessToken = res.accessToken;

        this.twilioService.connectToRoom(res.token, { name: res.roomName, audio: true, video: { height: 720, frameRate: 24, width: 1280 },
            logLevel: 'debug',
            bandwidthProfile: {
                video: {
                    mode: 'grid',
                    maxTracks: 10,
                    renderDimensions: {
                        high: {height: 1080, width: 1980},
                        standard: {height: 1080, width: 1980},
                        low: {height: 1080, width: 1980}
                    }
                }
            },
            maxAudioBitrate: 16000,
            preferredVideoCodecs: [{ codec: 'VP8', simulcast: true }],
            networkQuality: {local: 1, remote: 1} });

        this.audio.pause('play');
        await this.spinner.hide();

    }

    async stopRing() {
        console.log('stopping ring');
        this.audio.pause('play');
        await this.spinner.hide();
    }

    disconnectWebCall() {
        const roomName = document.getElementById('join-incoming-call-notification').dataset.roomname;
        this.audio.pause('play');
        if (this.twilioService.roomObj && this.twilioService.roomObj !== null) {
            this.twilioService.roomObj.disconnect();
            this.socketsService.disconnectCall();
            /*if (this.userService.isDoctor) {
               // this.sessionService.onSelected;
                    this.nav.navigateForward([`/patient/session/${session.id}`]);
                }*/
            const roomSize = this.twilioService.checkRoomSize();
            if (roomSize === 1) {
                console.log('roomSize = ' + roomSize);
                this.socketsService.lastOneInRoom(roomName);
            }
            // if (cordova) { this.disconnectCall(); }
            this.routeOnClose();
        } else {
           // if (cordova) { this.disconnectCall(); }
            this.routeOnClose();
        }
    }

    declineWebCall() {
        const roomName = document.getElementById('join-incoming-call-notification').dataset.roomname;
        this.audio.pause('play');
        this.spinner.hide();
        if (this.twilioService.roomObj && this.twilioService.roomObj !== null) {
            this.routeOnClose();
        }
        document.getElementById('socket-notifications').style.display = 'none';
        document.getElementById('incoming-call-declined-notification').style.display = 'none';
        document.getElementById('incoming-call-notification').style.display = 'none';
    }

    therapistStopsWebCall() {
        this.audio.pause('play');
        console.log('therapistStopsWebCall function');
        this.spinner.hide();
        const roomName = document.getElementById('join-incoming-call-notification').dataset.roomname;
        if (this.twilioService.roomObj && this.twilioService.roomObj !== null) {
            this.twilioService.roomObj.disconnect();
            this.twilioService.roomObj = null;
            this.socketsService.therapistStopsWebCall(roomName);
            this.routeOnClose();
        }
        this.routeOnClose();
    }


    async shareScreen() {
        const token = document.getElementById('join-incoming-call-notification').dataset.token;
        const roomName = document.getElementById('join-incoming-call-notification').dataset.roomname;
        const isSafari = /^((?!chrome|android).)*safari/i.test(navigator.userAgent);

        if (isSafari === true) {
            // Default constraints
            const constraints = { audio: true, video: true };
            navigator.mediaDevices.getUserMedia(constraints).then(stream  => {
                if (this.twilioService.roomObj && this.twilioService.roomObj !== null) {
                    this.twilioService.attachScreenShareTrack(stream, this.twilioService.roomObj.localParticipant);
                    this.socketsService.attachScreenShareTrack(this.twilioService.roomObj.name, this.twilioService.roomObj.localParticipant.identity);
                }
            });
        } else {
            const mediaDevices = navigator.mediaDevices as any;
            const stream = await mediaDevices.getDisplayMedia();

            // console.log(stream);
            const screenTrack = new LocalVideoTrack(stream.getTracks()[0]);
            if (this.twilioService.roomObj && this.twilioService.roomObj !== null) {
                this.twilioService.attachScreenShareTrack(screenTrack, this.twilioService.roomObj.localParticipant);
                this.socketsService.attachScreenShareTrack(this.twilioService.roomObj.name, this.twilioService.roomObj.localParticipant.identity);
            }
        }
    }

    addRecipients() {
        this.nav.navigateForward([`/viewers`]);
    }

    switchSizes() {
        const remoteDiv = document.getElementById('remote');
        const localDiv = document.getElementById('local');
        const remoteVideoContent0 = document.getElementById('remote').getElementsByTagName('video')[0];
        const localVideoContent0 = document.getElementById('local').getElementsByTagName('video')[0];
        remoteDiv.appendChild(localVideoContent0);
        localDiv.appendChild(remoteVideoContent0);
    }

    saveAs(uri, filename) {

        const link = document.createElement('a');

        if (typeof link.download === 'string') {
            link.href = uri;
            link.download = filename;
            document.body.appendChild(link);
            link.click();
            document.body.removeChild(link);
        } else {

            window.open(uri);

        }
    }

     onError(error) {
        console.log(`Error: ${error}`);
    }

    addOnPageLoad() {
        window.addEventListener('DOMContentLoaded', event => {
            const scrollX = document.documentElement.dataset.scrollX || 0;
            const scrollY = document.documentElement.dataset.scrollY || 0;
            if (typeof scrollX === 'number') {
                if (typeof scrollY === 'number') {
                    window.scrollTo(scrollX, scrollY);
                }
            }
        });
    }

    // Set the canvas size to the video size.
    setCanvasSizeToVideo(canvas, video) {
        canvas.style.height = video.clientHeight + 'px';
    }

    takeLocalVideoSnapshot(video, canvas) {
        // const context = this.snapshot.getContext('2d');
        // context.clearRect(0, 0, this.snapshot.width, this.snapshot.height);
        // context.drawImage(video, 0, 0, this.snapshot.width, this.snapshot.height);
    }


    toggleAudio() {
        this.twilioService.toggleAudio();
        if (document.getElementById('muteText').innerText === 'Mute') {
            document.getElementById('muteText').innerText = 'Unmute';
            document.getElementById('muteImage').setAttribute( 'src', 'assets/mute.png' );
        } else {
            document.getElementById('muteText').innerText = 'Mute';
            document.getElementById('muteImage').setAttribute( 'src', 'assets/mute_slash.png' );
        }
    }

    toggleVideo() {
        const elem = document.createElement('img');
        elem.style.zIndex = '1000000000';
        this.twilioService.toggleVideo();
        const roomName = document.getElementById('join-incoming-call-notification').dataset.roomname;
        this.socketsService.toggleVideo(roomName);
        const localDiv = document.getElementById('local');
        const localDiv2 = document.getElementById('local2');
        if (document.getElementById('muteVideoText').innerText === 'Camera') {

            const img = this.userService.user.picture;
            localDiv2.innerHTML = '<img src="' + img + '">';
            localDiv2.style.display = 'inline-block';
            localDiv.style.display = 'none';
            document.getElementById('muteVideoText').innerText = 'Start Camera';
            document.getElementById('muteVideoImage').setAttribute( 'src', 'assets/video_camera.png' );
        } else {
            // localDiv2.innerHTML = '';
            localDiv2.style.display = 'none';
            localDiv.style.display = 'inline-block';
            // document.getElementById('local').removeChild(elem);
            document.getElementById('muteVideoText').innerText = 'Camera';
            document.getElementById('muteVideoImage').setAttribute( 'src', 'assets/video_camera_slash.png' );
            // document.getElementById('muteVideoButton').innerText
        }
    }



}
