import { Component, OnInit, ViewChild } from '@angular/core';
import { Unsubscriber } from '../common/unsubscriber';
import { NavController, IonContent, ModalController } from '@ionic/angular';
import { CommunicationService } from 'src/app/services/communication.service';
import { ExplainerComponent } from '../notifications/explainer/explainer.component';
import { ToastService } from 'src/app/services/toast.service';

@Component({
  selector: 'app-viewers',
  templateUrl: './viewers.component.html',
  styleUrls: ['./viewers.component.scss'],
})
export class ViewersComponent extends Unsubscriber implements OnInit {
  @ViewChild(IonContent) content: IonContent;
  public pageTitle = 'Select Viewers';
  public patients;
  public contacts;
  public showNextButton = false;

  constructor(
    private communicationService: CommunicationService,
    private nav: NavController,
    private modalCtrl: ModalController,
    private toast: ToastService,
  ) {
    super();
   }

  ngOnInit() {
    this.openExplainerModal({type: 'VIDEO'});

    this.getViewers();
  }

  ionViewDidLeave() {
    this.content.scrollToTop();
    this.getViewers();
  }

  getViewers() {
    this.communicationService.getContacts().subscribe((res) => {
      res.forEach(c => c.isSelected = false);
      this.contacts = res;
    });
  }

  async getFilteredViewers(ev: any) {
    this.contacts = await this.communicationService.getContacts().toPromise();

    const val = ev.target.value;

    if (val && val.trim() !== '') {
      this.contacts = this.contacts.filter((recipient) => {
        const recipientFullName = recipient.first_name + ' ' + recipient.last_name;
        return (recipientFullName.toLowerCase().indexOf(val.toLowerCase()) > -1);
      });
    }
  }

  onChange() {
    const selectedContactIds = this.contacts.filter(c => c.isSelected).map(c => c.user_id);
    if (selectedContactIds.length > 1 || selectedContactIds.length < 1) {
      this.showNextButton = false;

      if (selectedContactIds.length > 1) {
        this.toast.presentToast('Please select only one person to video call. Multiple people in a room is coming in May!');
      }
    } else {
      this.showNextButton = true;
    }
  }

  startVideoCall() {
    const selectedContactIds = this.contacts.filter(c => c.isSelected).map(c => c.user_id);
    this.communicationService.createNewCall(selectedContactIds);
    this.nav.navigateForward(`/video`);
  }

  async openExplainerModal(notification) {
    const modal = await this.modalCtrl.create({
      component: ExplainerComponent,
      componentProps: {
        notification
      }
    });

    await modal.present();
  }
}
