import { Injectable } from '@angular/core';
import {
  HttpEvent,
  HttpInterceptor,
  HttpHandler,
  HttpRequest,
  HttpHeaders
} from '@angular/common/http';
import { Observable} from 'rxjs';
import { mergeMap } from 'rxjs/operators';

import { TokenService } from '../services/token.service';
import { HttpService } from '../services/http.service';

@Injectable()
export class AuthInterceptor implements HttpInterceptor {

  constructor(
    private tokenService: TokenService,
    private httpService: HttpService) {}

  intercept(req: HttpRequest<any>, next: HttpHandler): Observable<HttpEvent<any>> {
    if (req.url.includes('X-Amz-Credential') || req.url.includes('X-Amz-Signature')) {
      // Don't add Bearer token if call to S3 pre-signed URL
      return next.handle(req);
    }

    req = req.clone({
      url: encodeURI(req.url),
      setHeaders: {
        Authorization: `Bearer ${this.tokenService.token}`,
        'X-TW-NTW': this.httpService.network.getValue()
      }
    });
    return next.handle(req);
  }
}
