import {Injectable, NgZone} from '@angular/core';
import {Platform} from '@ionic/angular';
import {NativeAudio} from '@ionic-native/native-audio/ngx';

interface Sound {
    key: string;
    asset: string;
}

@Injectable({
    providedIn: 'root'
})
export class AudioService {

    private sounds: Sound[] = [];
    private audioPlayer: HTMLAudioElement = new Audio();
    private forceWebAudio = false;
    private isNative = false;

    constructor(private platform: Platform,
                private nativeAudio: NativeAudio,
                public ngZone: NgZone) {
        platform.ready().then(() => {
            if (platform.is('cordova')) {
                this.isNative = true;
            }
        });
    }

    preload(key: string, asset: string): void {

        if (!this.sounds.filter((sound) => sound.key === key).length) {
            if (this.isNative && !this.forceWebAudio) {
                this.platform.ready()
                    .then(() => this.nativeAudio.preloadComplex(key, asset, 1, 1, 0));
                this.sounds.push({
                    key,
                    asset
                });
            } else {
                const audio = new Audio();
                audio.src = asset;
                this.sounds.push({
                    key,
                    asset
                });
            }
        }
    }

    play(key: string): boolean {
        const soundToPlay: Sound = this.sounds.find((sound) => sound.key === key);

        if (soundToPlay) {
            if (this.isNative) {
                this.platform.ready()
                .then(() => this.nativeAudio.loop(soundToPlay.key)
                    .then((res) => console.log(res),
                        (err) => console.log('play error', JSON.stringify(soundToPlay), err))
                );
            } else {
                this.audioPlayer.src = soundToPlay.asset;
                this.audioPlayer.loop = true;
                this.audioPlayer.play()
                    .catch(() => {}); // ignore web player errors
            }
            return true;
        } else {
            return false;
        }
    }

    pause(key: string) {
        const soundToPlay: Sound = this.sounds.find((sound) => sound.key === key);

        if (this.isNative) {
            this.platform.ready()
            .then(() => this.nativeAudio.stop(soundToPlay.key)
                .then((res) => console.log(res),
                (err) => console.log('stop error', JSON.stringify(soundToPlay), err))
            );

            this.platform.ready()
            .then(() => this.nativeAudio.unload(soundToPlay.key)
                .then((res) => console.log(res),
                (err) => console.log('unload error', JSON.stringify(soundToPlay), err))
            );
        } else {
            this.audioPlayer.pause();
        }
    }

    getSounds() {
        return this.sounds;
    }

}
