import { Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { environment } from 'src/environments/environment';
import { IGoal } from '../models/server/goal';
import { Observable, BehaviorSubject } from 'rxjs';
import { IHistory } from '../models/server/history';

export interface IProgress {
  percentage: number;
  notes: string;
}

export interface IGoalType {
  id: string;
  name: string;
  list_order: number;
}

export interface IGoalsResponse {
  goals: IGoal[];
}

@Injectable({
  providedIn: 'root'
})
export class GoalService {
  private _history: BehaviorSubject<IHistory[]> = new BehaviorSubject([]);
  private _goal: BehaviorSubject<IGoal | {}> = new BehaviorSubject({});
  private dataStore: { history: IHistory[], goal: IGoal | {} } = { history: [], goal: {} };

  constructor(
    private http: HttpClient
  ) { }

  get goalHistory() {
    return this._history.asObservable();
  }

  get goal() {
    return this._goal.asObservable();
  }

  getGoals(patientId: string): Observable<IGoalsResponse> {
    return this.http.get<IGoalsResponse>(`${environment.API_URL}/api/patients/${patientId}/goals`);
  }

  getGoal(goalId: string): void {
    this.http.get<IGoal>(`${environment.API_URL}/api/goals/${goalId}`).subscribe((res) => {
      this.dataStore.goal = res;
      this._goal.next(Object.assign({}, this.dataStore).goal);
    }, error => console.log('couldn\'t fetch goal'));
  }

  getGoalTypes(): Observable<IGoalType[]> {
    return this.http.get<IGoalType[]>(`${environment.API_URL}/api/goaltypes`);
  }

  createGoal(goal: IGoal) {
    return this.http.post<IGoal>(`${environment.API_URL}/api/goals`, goal);
  }

  updateGoal(goalId: string, goal: IGoal) {
    return this.http.put<IGoal>(`${environment.API_URL}/api/goals/${goalId}`, goal);
  }

  deleteGoal(goalId: string) {
    return this.http.delete(`${environment.API_URL}/api/goals/${goalId}`);
  }

  updateGoalProgress(goalId: string, progress: IProgress) {
    return this.http.post<IProgress>(`${environment.API_URL}/api/goals/${goalId}/progress`, progress);
  }

  getGoalHistory(goalId: string) {
    this.http.get<IHistory[]>(`${environment.API_URL}/api/goals/${goalId}/history`).subscribe((res) => {
      this.dataStore.history = res;
      this._history.next(Object.assign({}, this.dataStore).history);
    }, error => console.log('couldn\'t fetch history'));
  }
}
