import { Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { Observable, BehaviorSubject } from 'rxjs';
import { GetPatientsResponse, GetPatientResponse } from '../models/Http';
import { environment } from 'src/environments/environment';
import { Patient } from '../models/Server';
import { WorkoutService } from './workout.service';

@Injectable({
  providedIn: 'root'
})
export class PatientService {
  patients: BehaviorSubject<Patient[]> = new BehaviorSubject<Patient[]>([]);
  currentPatient: BehaviorSubject<Patient> = new BehaviorSubject<Patient>(null);
  constructor(
    private http: HttpClient,
    private workoutService: WorkoutService
  ) { }

  getPatients() {
    this.http.get<GetPatientsResponse>(`${environment.API_URL}/api/patients`).subscribe((res: GetPatientsResponse) => {
      this.patients.next(res.patients);
      if (res.patients.length) {
        this.setCurrentPatient(res.patients[0]);
      }
    });
  }

  getPatient(patientId: string): Observable<GetPatientResponse> {
    return this.http.get<GetPatientResponse>(`${environment.API_URL}/api/patients/${patientId}`);
  }

  setCurrentPatient(patient: Patient) {
      this.currentPatient.next(patient);
      this.workoutService.updateDailyWorkout(patient.id);
  }

  getGuardians() {
    return this.http.get<any>(`${environment.API_URL}/api/patients/${this.currentPatient.value.id}/guardians`);
  }

  getGuardiansUsingPatientId(patientId: string) {
    return this.http.get<any>(`${environment.API_URL}/api/patients/${patientId}/guardians`);
  }

  updateDateOfBirth(patientId: string, dateOfBirth: string) {
    return this.http.put(`${environment.API_URL}/api/patients/${patientId}/dob`, {dateOfBirth});
  }

  updateNotes(patientId: string, notes: string) {
    return this.http.put(`${environment.API_URL}/api/patients/${patientId}/notes`, {notes});
  }
}
