import {Injectable} from '@angular/core';
import * as io from 'socket.io-client';
import { environment } from 'src/environments/environment';
import {UserService} from './user.service';
import {StateService} from './state.service';
import { CommunicationService } from 'src/app/services/communication.service';
import {AudioService} from './audio.service';
import {NgxSpinnerService} from 'ngx-spinner';
import {TwilioService} from './twilio.service';
// import { VideoComponent } from '../components/video/video.component';

@Injectable({
  providedIn: 'root'
})

export class SocketsService {
    socket: SocketIOClient.Socket;
    messageAll = [];
    messageRoom = [];
    private platform: any;

    constructor(
        private userService: UserService,
        private stateService: StateService,
        private communicationService: CommunicationService,
        private audio: AudioService,
        private spinner: NgxSpinnerService,
        public twilioService: TwilioService,
        // public videoComponent: VideoComponent,

    ) {

        this.platform = this.stateService.getPlatform();


        // for fullcycle dev server
        // this.socket = io(environment.SOCKET_URL, {  path: '/chat' });
        // for all other servers
        this.socket = io(environment.SOCKET_URL);
    }

    private userId: string;

    connect() {
        this.userId = this.userService.userId;
        this.makeUserRoom();

        this.socket.on('connect', () => {
            console.log(this.socket.id);
           // this.makeUserRoom(userId);
            this.makeUserRoom();
        });

        // send message
        this.socket.emit('message-all', 'msg all');

        // send message
        this.socket.emit('message-room', {
             room: '123',
             message: 'Connection ho gyaa'
        });

        // receive message
        this.socket.on('message-all', (data) => {
            console.log('message for all user - ' + data);
            this.messageAll.push(data);
        });

        // receive message
        this.socket.on('message-room', (data) => {
            console.log('message for personal room - ' + data.message);
            this.messageRoom.push(data.message);
        });

        // receive message
        this.socket.on('join', (data) => {
            console.log(data);
            // this.messageRoom.push(data.message);
        });

        // receive message
        this.socket.on('start-ring', (data) => {
            console.log(data);
            this.audio.preload('play', 'assets/sounds/videocall.mp3');
            this.audio.play('play');
        });

        // receive message
        this.socket.on('incoming-call', (data) => {
            // console.log(data);

            // console.log(data.token);
            // console.log(data.roomName);

            this.communicationService.setIncomingCall({
                token: data.token,
                roomName: data.roomName,
            });

            // console.log(data.token);

            setTimeout(() => {
                    console.log('Incoming video call from ' + data.Caller.Username);
                    this.spinner.hide();
                    document.getElementById('join-incoming-call-notification').setAttribute('data-token', data.token);
                    document.getElementById('join-incoming-call-notification').setAttribute('data-roomName', data.roomName);

                    document.getElementById('incoming-call-username').innerHTML = data.Caller.Username;
                    // document.getElementById('socket-notifications').style.display = 'inline-block';

                    if (this.stateService.getPlatform() === 'web') {
                        document.getElementById('incoming-call-notification').style.display = 'inline-block';
                        this.audio.preload('play', 'assets/sounds/videocall.mp3');
                        this.audio.play('play');
                    }



                        }
                        , 2000);


            // this.audio.preload('play', 'assets/sounds/videocall.mp3');


        });

        // receive message
        this.socket.on('decline-call', (data) => {
            console.log(data);
            this.messageRoom.push(data.message);
            this.audio.pause('play');
            this.spinner.hide();
            if (this.platform === 'web') {
                document.getElementById('socket-notifications').style.display = 'inline-block';
                document.getElementById('incoming-call-declined-notification').style.display = 'inline-block';
            }
            document.getElementById('incoming-call-notification').style.display = 'none';
            // this.videoComponent.disconnectWebCall();
            console.log('this.twilioService.roomObj');
            console.log(this.twilioService.roomObj);
            if (this.twilioService.roomObj && this.twilioService.roomObj !== null) {
                console.log('inside twilio disconnect');
                // this.twilioService.roomObj.disconnect();
                // this.twilioService.roomObj = null;
            }

            // this.nav.navigateForward([`/`]);


            setTimeout(() => {
                document.getElementById('socket-notifications').style.display = 'none';
                document.getElementById('incoming-call-declined-notification').style.display = 'none';
            }, 3000);
        });

        // receive message
        this.socket.on('attach-screen-share-track', (data) => {
            console.log(data);
            console.log('this.twilioService.roomObj');
            console.log(this.twilioService.roomObj);
            // document.getElementById('remoteVideoSmall').style.display = 'inline';
            this.twilioService.msgSubject.next('<div><img src="assets/screen_share-24px.svg" class="sharingMessage">\'' + data + '\' began sharing</div>');
        });

        // receive message
        this.socket.on('disconnect-call', (data) => {
            console.log(data);
            this.messageRoom.push(data.message);
        });

        // receive message
        this.socket.on('therapist-stops-web-call', (recipient) => {
            console.log('received therapist-stop-web-call socket call');
            document.getElementById('socket-notifications').style.display = 'none';
            document.getElementById('incoming-call-declined-notification').style.display = 'none';
            document.getElementById('incoming-call-notification').style.display = 'none';
        });


        // receive message
        this.socket.on('toggle-video', (picture) => {

            console.log('inside toggle-video socket call');
            this.twilioService.toggleRemoteVideo(picture);

        });

        // receive message
        this.socket.on('last-one-in-room', (recipient) => {
            console.log('this.userService.isDoctor = ' + this.userService.isDoctor);
            if (this.userService.isDoctor) {
                document.getElementById('last-one-in-room-doctor').style.display = 'inline';
            } else {
                document.getElementById('last-one-in-room-guardian').style.display = 'inline';
            }
        });

    }

    poorConnection() {
        this.socket.emit('poor-connection', this.userId);
    }

    startRing(calleeId) {
        this.socket.emit('start-ring', calleeId);
    }

    acceptCall() {
        console.log('accepted call');
        this.socket.emit('accept-call', this.userId);

    }

    declineCall(roomName) {
        console.log('declined call');
        this.socket.emit('decline-call', roomName);
        document.getElementById('socket-notifications').style.display = 'none';
        document.getElementById('incoming-call-declined-notification').style.display = 'none';
        document.getElementById('incoming-call-notification').style.display = 'none';
    }

    therapistStopsWebCall(roomName) {
        console.log('therapistStopsWebCall');
        this.socket.emit('therapist-stops-web-call', this.communicationService.recipientIds);
        document.getElementById('socket-notifications').style.display = 'none';
        document.getElementById('incoming-call-declined-notification').style.display = 'none';
        document.getElementById('incoming-call-notification').style.display = 'none';
    }

    lastOneInRoom(roomName) {
        if (this.userService.isDoctor) {
            this.socket.emit('last-one-in-room', roomName);
        } else {
            this.socket.emit('last-one-in-room', this.communicationService.recipientIds);
        }
    }

    disconnectCall() {
        console.log('disconnected call');
        this.socket.emit('disconnect-call', this.userId);
    }

    toggleVideo(roomName) {
        console.log('toggle video socket call');
        // this.socket.emit('toggle-video', {recipientIds: this.communicationService.recipientIds,  picture: this.userService.user.picture});
        console.log('roomName in toggleVideo');
        console.log(roomName);
        console.log('this.communicationService.recipientIds[0] in toggleVideo');
        console.log(this.communicationService.recipientIds[0]);
        if (roomName) {
            const userId = roomName.split('_');
            this.socket.emit('toggle-video', {userId: userId[0],  picture: this.userService.user.picture});
        } else {
            this.socket.emit('toggle-video', {userId: this.communicationService.recipientIds[0],  picture: this.userService.user.picture});
        }
    }

    attachScreenShareTrack(roomName, identity) {
        console.log('attach screen share track');
        console.log('roomName');
        console.log(roomName);
        console.log('identity');
        console.log(identity);
        // if (roomName) {
        //     const userId = roomName.split('_');
        //     this.socket.emit('attach-screen-share-track', {user: userId[0], identity});
        // } else {
        this.socket.emit('attach-screen-share-track', { user: this.communicationService.recipientIds[0], identity} );
        // }
    }

    detachScreenShareTrack(identity) {
        this.socket.emit('detach-screen-share-track', { user: this.communicationService.recipientIds[0], identity} );
    }

    makeUserRoom() {
        console.log(this.userId);
        this.socket.emit('join', this.userId);
        console.log('made user room');
    }



}
