import { Injectable } from '@angular/core';
import jwtDecode from 'jwt-decode';
import { StorageService } from './storage.service';

export interface DecodedToken {
  aud: string[];
  azp: string;
  exp: number;
  gty: string;
  iat: number;
  iss: string;
  scope: string;
  sub: string;
}

@Injectable({
  providedIn: 'root'
})
export class TokenService {

  token: string;

  constructor(private storage: StorageService) { }

  public async storeToken(token) {
    await this.storage.setObject('twAccessToken', token);
    await this.checkForToken();
  }

  public async checkForToken() {
    this.token = await this.storage.getObject('twAccessToken');
  }

  public async deleteToken() {
    await this.storage.deleteObject('twAccessToken');
    this.token = null;
  }

  public decodeJwt(jwt: string): DecodedToken {
    return jwtDecode(jwt);
  }

  public isTokenExpired(token: string): boolean {
    const decoded = this.decodeJwt(token);
    const delta = new Date().getTime() - (decoded.exp * 1000);
    return delta > 0;
  }
}
