import { Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { BehaviorSubject } from 'rxjs';
import { map } from 'rxjs/operators';
import * as moment from 'moment';
import { IWorkout } from '../models/server/workout';
import { environment } from 'src/environments/environment';

const fakeData = {
  patientId: '1234abc',
  sessionId: '1',
  currentStreak: 1,
  perfectWeeks: 3,
  currentWeek: [
    {
      date: moment().add(-1, 'days'),
      sessionId: '2',
      wasCompleted: false,
    },
    {
      date: moment(),
      sessionId: '4',
      wasCompleted: false
    },
    {
      date: moment().add(1, 'days'),
      sessionId: '3',
      wasCompleted: false,
    },
    {
      date: moment().add(2, 'days'),
      sessionId: '4',
      wasCompleted: false,
    },
    {
      date: moment().add(3, 'days'),
      sessionId: '4',
      wasCompleted: false,
    },
    {
      date: moment().add(4, 'days'),
      sessionId: '4',
      wasCompleted: false,
    },
    {
      date: moment().add(5, 'days'),
      sessionId: '4',
      wasCompleted: false,
    }
  ],
  videos: [
    {
      thumbnailUrl: 'assets/video-still.png',
      fileUrl: '',
      // video name???
      videoTags: ['tag1, tag2, tag3']
    },
    {
      thumbnailUrl: 'assets/video-still.png',
      fileUrl: '',
      // video name???
      videoTags: ['tag1, tag2, tag3']
    },
    {
      thumbnailUrl: 'assets/video-still.png',
      fileUrl: '',
      // video name???
      videoTags: ['tag1, tag2, tag3']
    }
  ],
  coachingNotes: `Lorem ipsum dolor sit amet, consectetur adipiscing elit. Nam dui enim,
  lacinia feugiat eros non, blandit feugiat urna. Duis sit amet ipsum nisl. Sed consectetur,
  est ut tincidunt bibendum, tellus neque maximus eros, at finibus nisi metus tincidunt nisi.`,
  isComplete: false
};

@Injectable({
  providedIn: 'root'
})
export class WorkoutService {
  public dailyWorkout$: BehaviorSubject<boolean> = new BehaviorSubject(true);

  constructor(private http: HttpClient) { }

  getDailyWorkout(patientId: string) {
    return this.http.get<IWorkout>(`${environment.API_URL}/api/patients/${patientId}/dailyworkout`).pipe(
      map((data) => {
        data.currentWeek.map((day) => {
          const mappedDay = day;
          if (moment(new Date()).isSame(day.date, 'day')) {
            mappedDay.isToday = true;
          }
          if (moment().isBefore(day.date)) {
            mappedDay.isFutureDate = true;
          }
          return mappedDay;
        });
        return data;
      })
    );
  }

  completeWorkout(patientId: string, sessionId: string) {
    return this.http.put(`${environment.API_URL}/api/patients/${patientId}/completeworkout`, { sessionId } );
  }

  setDailyWorkout(workout) {
    this.dailyWorkout$.next(workout);
  }

  updateDailyWorkout(patientId: string) {
    this.getDailyWorkout(patientId).subscribe((res) => {
      this.setDailyWorkout(res);
    });
  }
}
